@@ -1,6 +1,6 @@
 /* FSNBrowserCell.m
  *  
- * Copyright (C) 2004-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: March 2004
@@ -36,15 +36,6 @@
 static id <DesktopApplication> desktopApp = nil;
 
 static NSString *dots = @"...";
-static float dtslenght = 0.0;  
-static NSDictionary *fontAttr = nil;
-
-static NSFont *infoFont = nil;
-static int infoheight = 0;
-
-static SEL cutTitleSel = NULL;
-static cutIMP cutTitle = NULL;
-
 
 @implementation FSNBrowserCell
 
@@ -52,12 +43,11 @@ static cutIMP cutTitle = NULL;
 {
   RELEASE (selection);
   RELEASE (selectionTitle);
-  RELEASE (uncuttedTitle);
+  RELEASE (uncutTitle);
   RELEASE (extInfoType);
   RELEASE (infoCell); 
   RELEASE (icon); 
   RELEASE (selectedicon); 
-  RELEASE (dots);
   
   [super dealloc];
 }
@@ -67,29 +57,16 @@ static cutIMP cutTitle = NULL;
   static BOOL initialized = NO;
 
   if (initialized == NO) {
-    cutTitleSel = @selector(cutTitle:toFitWidth:);
-    cutTitle = (cutIMP)[self instanceMethodForSelector: cutTitleSel];   
-  
     if (desktopApp == nil) {
       NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
       NSString *appName = [defaults stringForKey: @"DesktopApplicationName"];
       NSString *selName = [defaults stringForKey: @"DesktopApplicationSelName"];
 
       if (appName && selName) {
-		    Class desktopAppClass = [[NSBundle mainBundle] classNamed: appName];
+        Class desktopAppClass = [[NSBundle mainBundle] classNamed: appName];
         SEL sel = NSSelectorFromString(selName);
         desktopApp = [desktopAppClass performSelector: sel];
       }
-
-      fontAttr = [NSDictionary dictionaryWithObject: [NSFont systemFontOfSize: 12]
-                                             forKey: NSFontAttributeName];
-      RETAIN (fontAttr);
-      dtslenght = [dots sizeWithAttributes: fontAttr].width;     
-      infoFont = [NSFont systemFontOfSize: 10];
-      infoFont = [[NSFontManager sharedFontManager] convertFont: infoFont 
-                                                    toHaveTrait: NSItalicFontMask];
-      RETAIN (infoFont);
-      infoheight = floor([[FSNodeRep sharedInstance] heighOfFont: infoFont]);
     }
    
     initialized = YES;
@@ -100,26 +77,27 @@ static cutIMP cutTitle = NULL;
 {
   self = [super init];
   
-  if (self) {       
-    node = nil;
-    selection = nil;
-    selectionTitle = nil;
-    showType = FSNInfoNameType;
-    extInfoType = nil;
-    icon = nil;
-    selectedicon = nil;
-    icnsize = DEFAULT_ISIZE;
-    
-    isLocked = NO;
-    iconSelected = NO;
-    isOpened = NO;
-    nameEdited = NO;
-    
-    [self setAllowsMixedState: NO];
-    
-    fsnodeRep = [FSNodeRep sharedInstance];
-  }
-
+  if (self)
+    {
+      node = nil;
+      selection = nil;
+      selectionTitle = nil;
+      showType = FSNInfoNameType;
+      extInfoType = nil;
+      icon = nil;
+      selectedicon = nil;
+      icnsize = DEFAULT_ISIZE;
+      
+      isLocked = NO;
+      iconSelected = NO;
+      isOpened = NO;
+      nameEdited = NO;
+      
+      [self setAllowsMixedState: NO];
+      
+      fsnodeRep = [FSNodeRep sharedInstance];
+    }
+  
   return self;
 }
 
@@ -171,6 +149,11 @@ static cutIMP cutTitle = NULL;
 - (NSString *)cutTitle:(NSString *)title 
             toFitWidth:(float)width
 {
+  NSDictionary *fontAttr;
+
+  fontAttr = [NSDictionary dictionaryWithObject: [NSFont systemFontOfSize: 12]
+			   forKey: NSFontAttributeName];
+
   if ([title sizeWithAttributes: fontAttr].width > width) {
     int tl = [title length];
   
@@ -224,7 +207,7 @@ static cutIMP cutTitle = NULL;
     NSColor *backcolor = [cvwin backgroundColor];
     float textlenght = cellFrame.size.width;
     BOOL showsFirstResponder = [self showsFirstResponder];
-    NSString *cuttitle;  
+    int infoheight = 0;
 
     titleRect = cellFrame;
 
@@ -238,15 +221,16 @@ static cutIMP cutTitle = NULL;
     }
 
     textlenght -= MARGIN;
-    ASSIGN (uncuttedTitle, [self stringValue]);
-    cuttitle = (*cutTitle)(self, cutTitleSel, uncuttedTitle, textlenght);
-    [self setStringValue: cuttitle];        
+    ASSIGN (uncutTitle, [self stringValue]);
+    [self setStringValue: [self cutTitle:uncutTitle toFitWidth:textlenght]];        
 
     [self setShowsFirstResponder: NO];
 
     if (icon == nil) {
       if (nameEdited == NO) {
         if (infoCell) {
+          infoheight = floor([[FSNodeRep sharedInstance] heightOfFont: [infoCell font]]);
+
           if (([self isHighlighted] || [self state]) && (nameEdited == NO)) {
 	          [[self highlightColorInView: controlView] set];
             NSRectFill(cellFrame);
@@ -366,7 +350,7 @@ static cutIMP cutTitle = NULL;
       NSDottedFrameRect(cellFrame);
     }
 
-    [self setStringValue: uncuttedTitle]; 
+    [self setStringValue: uncutTitle]; 
   }         
 }
 
@@ -411,7 +395,7 @@ static cutIMP cutTitle = NULL;
 
 - (void)showSelection:(NSArray *)selnodes
 {
-  int i;
+  NSUInteger i;
 
   ASSIGN (node, [selnodes objectAtIndex: 0]);
   ASSIGN (selection, selnodes);
@@ -419,8 +403,8 @@ static cutIMP cutTitle = NULL;
     ASSIGN (icon, [fsnodeRep multipleSelectionIconOfSize: icnsize]);
     icnh = [icon size].height;
   }  
-  ASSIGN (selectionTitle, ([NSString stringWithFormat: @"%i %@", 
-                  [selection count], NSLocalizedString(@"elements", @"")]));
+  ASSIGN (selectionTitle, ([NSString stringWithFormat: @"%lu %@", 
+                                     (unsigned long)[selection count], NSLocalizedString(@"elements", @"")]));
   [self setStringValue: selectionTitle];
 
   [self setLocked: NO];
@@ -446,7 +430,7 @@ static cutIMP cutTitle = NULL;
 {
   if (selection) {
     NSMutableArray *selpaths = [NSMutableArray array];
-    int i;
+    NSUInteger i;
 
     for (i = 0; i < [selection count]; i++) {
       [selpaths addObject: [[selection objectAtIndex: i] path]];
@@ -461,11 +445,9 @@ static cutIMP cutTitle = NULL;
 - (void)setFont:(NSFont *)fontObj
 {
   [super setFont: fontObj];
-  ASSIGN (fontAttr, [NSDictionary dictionaryWithObject: [self font] 
-                                                forKey: NSFontAttributeName]);
-  dtslenght = [dots sizeWithAttributes: fontAttr].width;     
 }
 
+
 - (NSFont *)labelFont
 {
   return [super font];
@@ -522,10 +504,16 @@ static cutIMP cutTitle = NULL;
   
   if (showType == FSNInfoNameType) {
     DESTROY (infoCell);
-  } else if (infoCell == nil) {
-    infoCell = [NSCell new];
-    [infoCell setFont: infoFont];
   }
+  else if (infoCell == nil)
+    {
+      NSFont *infoFont;
+      
+      infoFont = [[NSFontManager sharedFontManager] convertFont: [self font] 	 
+                                                    toHaveTrait: NSItalicFontMask];
+      infoCell = [NSCell new];
+      [infoCell setFont: infoFont];
+    }
   
   switch(showType) {
     case FSNInfoKindType:
