@@ -1,8 +1,9 @@
 /* FSNIcon.m
  *  
- * Copyright (C) 2004-2016 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2021 Free Software Foundation, Inc.
  *
- * Author: Enrico Sersale <enrico@imago.ro>
+ * Authors: Enrico Sersale <enrico@imago.ro>
+ *          Riccardo Mottola <rm@gnu.org>
  * Date: March 2004
  *
  * This file is part of the GNUstep FSNode framework
@@ -39,6 +40,13 @@
 #define DOUBLE_CLICK_LIMIT  300
 #define EDIT_CLICK_LIMIT   1000
 
+/* we redefine the dockstyle to read the preferences without including Dock.h" */
+typedef enum DockStyle
+{
+  DockStyleClassic = 0,
+  DockStyleModern = 1
+} DockStyle;
+
 static id <DesktopApplication> desktopApp = nil;
 
 static NSImage *branchImage;
@@ -60,6 +68,7 @@ static NSImage *branchImage;
   RELEASE (highlightPath);
   RELEASE (label);
   RELEASE (infolabel);
+  RELEASE (labelFrameColor);
   [super dealloc];
 }
 
@@ -138,6 +147,20 @@ static NSImage *branchImage;
   return hname;
 }
 
+- (NSString*) description
+{
+  NSString *s;
+
+  s = [super description];
+  s = [s stringByAppendingString:@" {"];
+  s = [s stringByAppendingString:[node path]];
+  if ([node isMountPoint])
+    s = [s stringByAppendingString:@" isMountPoint "];
+  s = [s stringByAppendingString: [NSString stringWithFormat:@" gridIndex: %u", (unsigned)gridIndex]];
+  s = [s stringByAppendingString:@" }"];
+  return s;
+}
+
 - (id)initForNode:(FSNode *)anode
      nodeInfoType:(FSNInfoType)type
      extendedType:(NSString *)exttype
@@ -156,6 +179,7 @@ static NSImage *branchImage;
     NSFontManager *fmanager = [NSFontManager sharedFontManager];
     NSFont *infoFont;
     NSRect r = NSZeroRect;
+    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
     
     fsnodeRep = [FSNodeRep sharedInstance];
     
@@ -293,7 +317,17 @@ static NSImage *branchImage;
     
     dragdelay = 0;
     isDragTarget = NO;
-    onSelf = NO;    
+    onSelf = NO;
+
+    labelFrameColor = [NSColor controlColor];
+    if ([[defaults objectForKey: @"dockstyle"] intValue] == DockStyleModern)
+      {
+	labelFrameColor = [labelFrameColor colorUsingColorSpaceName:NSCalibratedRGBColorSpace];
+	labelFrameColor = [labelFrameColor colorWithAlphaComponent:0.5];
+      }
+    [labelFrameColor retain];
+
+    drawLabelBackground = NO;
   }
   
   return self;
@@ -566,7 +600,7 @@ static NSImage *branchImage;
   NSPoint location = [theEvent locationInWindow];
   NSPoint selfloc = [self convertPoint: location fromView: nil];
   BOOL onself = NO;
-	NSEvent *nextEvent = nil;
+  NSEvent *nextEvent = nil;
   BOOL startdnd = NO;
   NSSize offset;
 
@@ -574,7 +608,7 @@ static NSImage *branchImage;
     onself = [self mouse: selfloc inRect: icnBounds];
   } else {
     onself = ([self mouse: selfloc inRect: icnBounds]
-                        || [self mouse: selfloc inRect: labelRect]);
+	      || [self mouse: selfloc inRect: labelRect]);
   }
 
   if (onself) {
@@ -582,54 +616,54 @@ static NSImage *branchImage;
       return;
     }
     
-	  if ([theEvent clickCount] == 1) {
+    if ([theEvent clickCount] == 1) {
       if (isSelected == NO) {
         if ([container respondsToSelector: @selector(stopRepNameEditing)]) {
           [container stopRepNameEditing];
         }
       }
       
-		  if ([theEvent modifierFlags] & NSShiftKeyMask) {
+      if ([theEvent modifierFlags] & NSShiftKeyMask) {
         if ([container respondsToSelector: @selector(setSelectionMask:)]) {
           [container setSelectionMask: FSNMultipleSelectionMask];
         }
          
-			  if (isSelected) {
+	if (isSelected) {
           if ([container selectionMask] == FSNMultipleSelectionMask) {
-				    [self unselect];
+	    [self unselect];
             if ([container respondsToSelector: @selector(selectionDidChange)]) {
               [container selectionDidChange];	
             }
-				    return;
+	    return;
           }
         } else {
-				  [self select];
-			  }
+	  [self select];
+	}
         
-		  } else {
+      } else {
         if ([container respondsToSelector: @selector(setSelectionMask:)]) {
           [container setSelectionMask: NSSingleSelectionMask];
         }
         
         if (isSelected == NO) {
-				  [self select];
+	  [self select];
           
-			  } else {
+	} else {
           NSTimeInterval interval = ([theEvent timestamp] - editstamp);
         
           if ((interval > DOUBLE_CLICK_LIMIT) 
-                            && [self mouse: location inRect: labelRect]) {
+	      && [self mouse: location inRect: labelRect]) {
             if ([container respondsToSelector: @selector(setNameEditorForRep:)]) {
               [container setNameEditorForRep: self];
             }
           } 
         }
-		  }
+      }
     
       if (dndSource) {
         while (1) {
-	        nextEvent = [[self window] nextEventMatchingMask:
-    							                  NSLeftMouseUpMask | NSLeftMouseDraggedMask];
+	  nextEvent = [[self window] nextEventMatchingMask:
+				       NSLeftMouseUpMask | NSLeftMouseDraggedMask];
 
           if ([nextEvent type] == NSLeftMouseUp) {
             [[self window] postEvent: nextEvent atStart: NO];
@@ -641,8 +675,8 @@ static NSImage *branchImage;
             break;
 
           } else if (([nextEvent type] == NSLeftMouseDragged)
-                            && ([self mouse: selfloc inRect: icnBounds])) {
-	          if (dragdelay < 5) {
+		     && ([self mouse: selfloc inRect: icnBounds])) {
+	    if (dragdelay < 5) {
               dragdelay++;
             } else {    
               NSPoint p = [nextEvent locationInWindow];
@@ -667,7 +701,7 @@ static NSImage *branchImage;
       }
       
       editstamp = [theEvent timestamp];       
-	  } 
+    }
     
   } else {
     [container mouseDown: theEvent];
@@ -727,6 +761,8 @@ static NSImage *branchImage;
     {
       if (nameEdited == NO)
         {
+          [label setBackgroundColor:labelFrameColor];
+          [label setDrawsBackground: drawLabelBackground];
           [label drawWithFrame: labelRect inView: self];
         }
       
