@@ -1,6 +1,6 @@
 /* MDKQuery.m
  *  
- * Copyright (C) 2006-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2006-2018 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@dtedu.net>
  * Date: August 2006
@@ -133,7 +133,7 @@ enum {
   TEST_RELEASE (groupedResults);
   TEST_RELEASE (fsfilters);
   
-	[super dealloc];
+  [super dealloc];
 }
 
 + (void)initialize
@@ -242,7 +242,7 @@ enum {
   NSDictionary *domain = [defaults persistentDomainForName: @"MDKQuery"];
   NSArray *userSet = [domain objectForKey: @"user-attributes"];
   NSMutableDictionary *attributes = [NSMutableDictionary dictionary];
-  unsigned i;
+  NSUInteger i;
 
   for (i = 0; i < [attrNames count]; i++) {
     NSString *attrname = [attrNames objectAtIndex: i];
@@ -492,7 +492,7 @@ enum {
 
 - (MDKQuery *)queryWithDestTable:(NSString *)tab
 {
-  unsigned i;
+  NSUInteger i;
   
   if ([destTable isEqual: tab]) {
     return self;
@@ -585,7 +585,7 @@ enum {
 
   if (parentQuery) {
     NSArray *subs = [parentQuery subqueries];
-    unsigned index = [subs indexOfObject: self];
+    NSUInteger index = [subs indexOfObject: self];
     
     if (index > 0) {
       sibling = [subs objectAtIndex: index - 1];
@@ -768,7 +768,7 @@ enum {
 - (BOOL)buildQuery
 {
   if ([self isClosed]) {
-    unsigned i;
+    NSUInteger i;
     
     status |= BUILT;
     
@@ -885,7 +885,7 @@ enum {
 - (NSString *)description
 {
   NSMutableString *descr = [NSMutableString string];
-  unsigned i;
+  NSUInteger i;
   
   if ([self isRoot] == NO) {
     [descr appendString: @"("];
@@ -1188,8 +1188,8 @@ enum {
   [sqlstr appendFormat: @"AND attributes.path_id = %@.id ", srcTable];      
 
   if (searchPaths) {
-    unsigned count = [searchPaths count];
-    unsigned i;
+    NSUInteger count = [searchPaths count];
+    NSUInteger i;
 
     [sqlstr appendString: @"AND ("];
 
@@ -1760,13 +1760,13 @@ enum {
   }
   
   if (sort) {
-    unsigned count = [nodes count];    
-    int ins = 0;
+    NSUInteger count = [nodes count];    
+    NSUInteger ins = 0;
 
     if (count) {
-      int first = 0;
-      int last = count;
-      int pos = 0; 
+      NSUInteger first = 0;
+      NSUInteger last = count;
+      NSUInteger pos = 0; 
       NSComparisonResult result;
 
       while (1) {
@@ -1775,7 +1775,7 @@ enum {
           break;
         }
 
-        pos = (int)((first + last) / 2);
+        pos = (NSUInteger)((first + last) / 2);
 
         result = [(NSNumber *)[scores objectAtIndex: pos] compare: score];
 
@@ -1986,9 +1986,9 @@ enum {
   }
 
   if ([self scanString: @"(" intoString: NULL]) {
-    PARSEXCEPT (!(((parsed & SUBOPEN) == SUBOPEN) 
+    PARSEXCEPT ((!(((parsed & SUBOPEN) == SUBOPEN) 
                       || ((parsed & COMPOUND) == COMPOUND)
-                      || ((parsed == 0) && (currentQuery == rootQuery))), 
+                  || ((parsed == 0) && (currentQuery == rootQuery)))), 
                                       @"subquery without compound operator");
     parsed &= ~(COMPOUND | SUBCLOSE | COMPARISION);  
     parsed |= SUBOPEN;
@@ -2146,7 +2146,7 @@ enum {
 
 - (BOOL)scanQueryKeyword:(NSString *)key
 {
-  unsigned loc = [self scanLocation];
+  NSUInteger loc = [self scanLocation];
   
   [self setCaseSensitive: NO];
   
@@ -2201,8 +2201,8 @@ static NSString *path_sep(void)
 
 BOOL subPathOfPath(NSString *p1, NSString *p2)
 {
-  int l1 = [p1 length];
-  int l2 = [p2 length];  
+  NSUInteger l1 = [p1 length];
+  NSUInteger l2 = [p2 length];  
 
   if ((l1 > l2) || ([p1 isEqual: p2])) {
     return NO;
