@@ -1,6 +1,6 @@
 /* mdextractor.m
  *  
- * Copyright (C) 2006-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2006-2018 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@dtedu.net>
  * Date: February 2006
@@ -81,26 +81,53 @@ static void path_exists(sqlite3_context *context, int argc, sqlite3_value **argv
 
 static void path_moved(sqlite3_context *context, int argc, sqlite3_value **argv)
 {
+  // FIXME: This code also exists in GWMetadata/gmds/gmds/gmds.m.
+  // It may be useful to move it to a library.
+
+  // old dirname, and its length
   const unsigned char *oldbase = sqlite3_value_text(argv[0]);
   int oldblen = strlen((const char *)oldbase);
+
+  // new dirname, and its length
   const unsigned char *newbase = sqlite3_value_text(argv[1]);
   int newblen = strlen((const char *)newbase);
+
+  // old full path, and its length
   const unsigned char *oldpath = sqlite3_value_text(argv[2]);
   int oldplen = strlen((const char *)oldpath);
-  char newpath[PATH_MAX] = "";
+
+  // new full path, and its length
+  char *newpath = NULL;
+  int newplen = newblen + (oldplen - oldblen);
+
   int i = newblen;
   int j;
-  
-  strncpy(newpath, (const char *)newbase, newblen);  
-  
+
+  /////
+
+  // allocate space for new path + nul terminator
+  newpath = malloc(newplen + 1);
+
+  // copy the new dirname over, but restrict up to allocated space.
+  // add a null terminator in case the newbase is exactly newplen
+  // in size.
+  strncpy(newpath, (const char *)newbase, newplen);
+  newpath[newplen] = '\0';
+
+  // concatenate the new pathname.
+  // equivalent of: strncat(newpath, oldpath+oldblen, newplen),
+  // which may be safer as it will also add a nul terminator at
+  // newpath[newplen].
   for (j = oldblen; j < oldplen; j++) {
     newpath[i] = oldpath[j];
     i++;
   }
-  
   newpath[i] = '\0';
-  
+
+  // return the path.
   sqlite3_result_text(context, newpath, strlen(newpath), SQLITE_TRANSIENT);
+
+  free(newpath);
 }
 
 static void time_stamp(sqlite3_context *context, int argc, sqlite3_value **argv)
@@ -235,7 +262,7 @@ static void time_stamp(sqlite3_context *context, int argc, sqlite3_value **argv)
     [conn setDelegate: self];
 
     if ([conn registerName: @"mdextractor"] == NO) {
-	    NSLog(@"unable to register with name server - quiting.");
+	    NSLog(@"unable to register with name server - quitting.");
 	    DESTROY (self);
 	    return self;
 	  }
@@ -533,8 +560,8 @@ static void time_stamp(sqlite3_context *context, int argc, sqlite3_value **argv)
 
       if (sleeps >= 10) {
         NSLog(@"Unable to obtain lock %@", indexedStatusLock);
-        return [NSDictionary dictionary];
-	    }
+        return [NSArray array];
+      }
     }
 
     status = [NSArray arrayWithContentsOfFile: indexedStatusPath];
@@ -1594,12 +1621,10 @@ int main(int argc, char** argv)
   CREATE_AUTORELEASE_POOL(pool);
   NSProcessInfo *info = [NSProcessInfo processInfo];
   NSMutableArray *args = AUTORELEASE ([[info arguments] mutableCopy]);
-  static BOOL	is_daemon = NO;
   BOOL subtask = YES;
 
   if ([[info arguments] containsObject: @"--daemon"]) {
     subtask = NO;
-    is_daemon = YES;
   }
 
   if (subtask) {
