@@ -1,6 +1,6 @@
 /* updater.m
  *  
- * Copyright (C) 2006 Free Software Foundation, Inc.
+ * Copyright (C) 2006-2011 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@dtedu.net>
  * Date: February 2006
@@ -22,15 +22,18 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <Foundation/Foundation.h>
-#include <GNUstepBase/NSTask+GS.h>
-#include <AppKit/AppKit.h>
+#include "config.h"
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <limits.h>
 #include <float.h>
-#include "mdextractor.h"
-#include "config.h"
+
+#import <Foundation/Foundation.h>
+#import <AppKit/AppKit.h>
+
+#import "mdextractor.h"
+
 
 #define GWDebugLog(format, args...) \
   do { if (GW_DEBUG_LOG) \
@@ -493,7 +496,7 @@ do { \
     NSMutableDictionary *dict = [NSMutableDictionary dictionary];  
     NSString *path = [info objectForKey: @"path"];
     NSString *event = [info objectForKey: @"event"];
-    NSNumber *exists;
+    NSNumber *exists = nil;
 
     if ([event isEqual: @"GWWatchedPathDeleted"]) {
       exists = [NSNumber numberWithBool: NO];
@@ -859,11 +862,14 @@ do { \
 
 - (void)setupScheduledUpdater
 {
+  NSString *query;
+  NSArray *lines;
+  NSUInteger i;
+
   CREATE_AUTORELEASE_POOL(arp);
-  NSString *query = @"SELECT path FROM paths WHERE is_directory = 1";
-  NSArray *lines = [sqlite resultsOfQuery: query];
-  unsigned i;
-    
+  query = @"SELECT path FROM paths WHERE is_directory = 1";
+  lines = [sqlite resultsOfQuery: query];
+
   directories = [NSMutableArray new];
                                        
   for (i = 0; i < [lines count]; i++) {
@@ -886,15 +892,20 @@ do { \
 {
   if (extracting == NO) {
     CREATE_AUTORELEASE_POOL(arp);
-    unsigned count = [directories count];
+    NSUInteger count = [directories count];
     NSString *dir;
     NSDictionary *attributes;
     BOOL dirok;
-    unsigned i;
+    NSUInteger i;
   
-    if ((dirpos >= count) || (dirpos < 0)) {
+    if (count == 0)
+      {
+	RELEASE(arp);
+	return;
+      }
+
+    if ((dirpos >= count) || (dirpos < 0))
       dirpos = 0;
-    }
   
     dir = [directories objectAtIndex: dirpos];
     attributes = [fm fileAttributesAtPath: dir traverseLink: NO];
@@ -909,7 +920,6 @@ do { \
       NSString *query;
       SQLitePreparedStatement *statement;
       NSArray *results;
-      unsigned i;
       
       query = @"SELECT path, moddate FROM paths "
               @"WHERE path > :minpath "
