@@ -1,6 +1,6 @@
 /* Dock.h
  *  
- * Copyright (C) 2005 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2005
@@ -22,12 +22,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#ifndef DOCK_H
-#define DOCK_H
 
-#include <AppKit/NSView.h>
-#include "GWDesktopManager.h"
-#include "FSNodeRep.h"
+#import <AppKit/NSView.h>
+#import "GWDesktopManager.h"
+#import "FSNodeRep.h"
 
 @class NSWindow;
 @class NSColor;
@@ -35,16 +33,22 @@
 @class DockIcon;
 @class GWorkspace;
 
+typedef enum DockStyle
+{   
+  DockStyleClassic = 0,
+  DockStyleModern = 1
+} DockStyle;
+
 @interface Dock : NSView 
 {
   DockPosition position;
+  DockStyle style;
+  BOOL singleClickLaunch;
 
   NSMutableArray *icons;
   int iconSize;
 
   NSColor *backColor;
-  NSImage *backImage;
-  BOOL useBackImage;
   
   DockIcon *dndSourceIcon;
   BOOL isDragTarget;
@@ -97,14 +101,16 @@
 
 - (void)iconMenuAction:(id)sender;
 
+- (void)setSingleClickLaunch:(BOOL)value;
+
 - (void)setPosition:(DockPosition)pos;
 
+- (DockStyle)style;
+
+- (void)setStyle:(DockStyle)s;
+
 - (void)setBackColor:(NSColor *)color;
 
-- (void)setBackImage;
-
-- (void)setUseBackImage:(BOOL)value;
-
 - (void)tile;
 
 - (void)updateDefaults;
@@ -152,5 +158,3 @@
 - (BOOL)isDragTarget;
 
 @end
-
-#endif // DOCK_H
