@@ -40,10 +40,11 @@
   BOOL trashFull;
   BOOL docked;
   BOOL launched;
-	BOOL launching;
+  BOOL launching;
   BOOL apphidden;  
   BOOL appactive;  
-  float dissFract;	
+  float dissFract;
+  int minimumLaunchClicks;
     
   NSColor *darkerColor;
   NSColor *highlightColor;
@@ -80,6 +81,8 @@
 
 - (BOOL)isDocked;
 
+- (void)setSingleClickLaunch:(BOOL)value;
+
 - (void)setLaunched:(BOOL)value;
 
 - (BOOL)isLaunched;
