@@ -1,8 +1,10 @@
 /* GWDesktopIcon.m
  *  
- * Copyright (C) 2005 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2021 Free Software Foundation, Inc.
+ *
+ * Authors: Enrico Sersale <enrico@imago.ro>
+ *          Riccardo Mottola <rm@gnu.org>
  *
- * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2005
  *
  * This file is part of the GNUstep GWorkspace application
@@ -28,13 +30,45 @@
 
 @implementation GWDesktopIcon
 
+- (id)initForNode:(FSNode *)anode
+     nodeInfoType:(FSNInfoType)type
+     extendedType:(NSString *)exttype
+         iconSize:(int)isize
+     iconPosition:(NSUInteger)ipos
+        labelFont:(NSFont *)lfont
+        textColor:(NSColor *)tcolor
+        gridIndex:(NSUInteger)gindex
+        dndSource:(BOOL)dndsrc
+        acceptDnd:(BOOL)dndaccept
+        slideBack:(BOOL)slback
+{
+  self = [super initForNode: anode
+	       nodeInfoType: type
+	       extendedType: exttype
+		   iconSize: isize
+	       iconPosition: ipos
+		  labelFont: lfont
+		  textColor: tcolor
+		  gridIndex: gindex
+		  dndSource: dndsrc
+		  acceptDnd: dndaccept
+		  slideBack: slback];
+
+  if (self)
+    {
+      drawLabelBackground = YES;
+    }
+
+  return self;
+}
+
 - (void)mouseDown:(NSEvent *)theEvent
 {
   NSWindow *win = [self window];
   NSPoint location = [theEvent locationInWindow];
   NSPoint selfloc = [self convertPoint: location fromView: nil];
   BOOL onself = NO;
-	NSEvent *nextEvent = nil;
+  NSEvent *nextEvent = nil;
   BOOL startdnd = NO;
   NSSize offset;
 
@@ -45,7 +79,7 @@
     onself = [self mouse: selfloc inRect: icnBounds];
   } else {
     onself = ([self mouse: selfloc inRect: icnBounds]
-                        || [self mouse: selfloc inRect: labelRect]);
+	      || [self mouse: selfloc inRect: labelRect]);
   }
 
   if (onself) {
@@ -53,45 +87,45 @@
       return;
     }
 
-	  if ([theEvent clickCount] == 1) {
+    if ([theEvent clickCount] == 1) {
       if (isSelected == NO) {
         [container stopRepNameEditing];
         [container repSelected: self];
       }
       
-		  if ([theEvent modifierFlags] & NSShiftKeyMask) {
+      if ([theEvent modifierFlags] & NSShiftKeyMask) {
         [container setSelectionMask: FSNMultipleSelectionMask];
          
-			  if (isSelected) {
+	if (isSelected) {
           if ([container selectionMask] == FSNMultipleSelectionMask) {
-				    [self unselect];
+	    [self unselect];
             [container selectionDidChange];	
-				    return;
+	    return;
           }
         } else {
-				  [self select];
-			  }
+	  [self select];
+	}
         
-		  } else {
+      } else {
         [container setSelectionMask: NSSingleSelectionMask];
         
         if (isSelected == NO) {
-				  [self select];
-			  }
-		  }
+	  [self select];
+	}
+      }
     
       if (dndSource) {
         while (1) {
-	        nextEvent = [win nextEventMatchingMask:
-    							                  NSLeftMouseUpMask | NSLeftMouseDraggedMask];
+	  nextEvent = [win nextEventMatchingMask:
+			     NSLeftMouseUpMask | NSLeftMouseDraggedMask];
 
           if ([nextEvent type] == NSLeftMouseUp) {
-            [win postEvent: nextEvent atStart: NO];
+            [win postEvent: nextEvent atStart: YES];
             break;
 
           } else if (([nextEvent type] == NSLeftMouseDragged)
-                            && ([self mouse: selfloc inRect: icnBounds])) {
-	          if (dragdelay < 5) {
+		     && ([self mouse: selfloc inRect: icnBounds])) {
+	    if (dragdelay < 5) {
               dragdelay++;
             } else {     
               NSPoint p = [nextEvent locationInWindow];
@@ -109,7 +143,7 @@
       }
       
       editstamp = [theEvent timestamp];       
-	  } 
+    }
     
   } else {
     [container mouseDown: theEvent];
