@@ -1,8 +1,10 @@
 /* GWDesktopManager.m
  *  
- * Copyright (C) 2005-2016 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2021 Free Software Foundation, Inc.
+ *
+ * Authors: Enrico Sersale <enrico@imago.ro>
+ *          Riccardo Mottola <rm@gnu.org>
  *
- * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2005
  *
  * This file is part of the GNUstep GWorkspace application
@@ -41,9 +43,10 @@ static GWDesktopManager *desktopManager = nil;
 
 + (GWDesktopManager *)desktopManager
 {
-	if (desktopManager == nil) {
-		desktopManager = [[GWDesktopManager alloc] init];
-	}	
+  if (desktopManager == nil)
+    {
+      desktopManager = [[GWDesktopManager alloc] init];
+    }
   return desktopManager;
 }
 
@@ -55,7 +58,7 @@ static GWDesktopManager *desktopManager = nil;
   RELEASE (win);
   RELEASE (dock);
   RELEASE (mpointWatcher);
-    
+
   [super dealloc];
 }
 
@@ -64,7 +67,7 @@ static GWDesktopManager *desktopManager = nil;
   self = [super init];
   
   if (self) {
-    NSUserDefaults *defaults;	
+    NSUserDefaults *defaults;
     id defentry;
     NSString *path;
     id window = nil;
@@ -83,6 +86,7 @@ static GWDesktopManager *desktopManager = nil;
 
     defaults = [NSUserDefaults standardUserDefaults];	
 
+    singleClickLaunch = [defaults boolForKey: @"singleclicklaunch"];
     defentry = [defaults objectForKey: @"dockposition"];
     dockPosition = defentry ? [defentry intValue] : DockPositionRight;
 
@@ -128,19 +132,19 @@ static GWDesktopManager *desktopManager = nil;
              object: nil];    
     
     [[ws notificationCenter] addObserver: self 
-                				  selector: @selector(newVolumeMounted:) 
-                					    name: NSWorkspaceDidMountNotification
-                					  object: nil];
+				selector: @selector(newVolumeMounted:)
+				    name: NSWorkspaceDidMountNotification
+				  object: nil];
 
     [[ws notificationCenter] addObserver: self 
-                				  selector: @selector(mountedVolumeWillUnmount:) 
-                					    name: NSWorkspaceWillUnmountNotification
-                					  object: nil];
+				selector: @selector(mountedVolumeWillUnmount:)
+				    name: NSWorkspaceWillUnmountNotification
+				  object: nil];
 
     [[ws notificationCenter] addObserver: self 
-                				  selector: @selector(mountedVolumeDidUnmount:) 
-                					    name: NSWorkspaceDidUnmountNotification
-                					  object: nil];
+				selector: @selector(mountedVolumeDidUnmount:)
+				    name: NSWorkspaceDidUnmountNotification
+				  object: nil];
 
     [self setContextHelp];
   }
@@ -198,12 +202,12 @@ static GWDesktopManager *desktopManager = nil;
 
   path = [NSHomeDirectory() stringByAppendingPathComponent: @".Trash"]; 
 
-	if ([fm fileExistsAtPath: path isDirectory: &isdir] == NO) {
+  if ([fm fileExistsAtPath: path isDirectory: &isdir] == NO) {
     if ([fm createDirectoryAtPath: path attributes: nil] == NO) {
       NSLog(@"Can't create the Recycler directory! Quitting now.");
       [NSApp terminate: self];
     }
-	}
+  }
 }
 
 - (void)setUsesXBundle:(BOOL)value
@@ -287,6 +291,18 @@ static GWDesktopManager *desktopManager = nil;
   return desktopView;
 }
 
+
+- (BOOL)singleClickLaunch
+{
+  return singleClickLaunch;
+}
+
+- (void)setSingleClickLaunch:(BOOL)value
+{
+  singleClickLaunch = value;
+  [dock setSingleClickLaunch:singleClickLaunch];
+}
+
 - (Dock *)dock
 {
   return dock;
@@ -411,7 +427,7 @@ static GWDesktopManager *desktopManager = nil;
 }
 
 - (BOOL)selectFile:(NSString *)fullPath
-											inFileViewerRootedAtPath:(NSString *)rootFullpath
+inFileViewerRootedAtPath:(NSString *)rootFullpath
 {
   return [gworkspace selectFile: fullPath inFileViewerRootedAtPath: rootFullpath];
 }
@@ -441,7 +457,7 @@ static GWDesktopManager *desktopManager = nil;
   }
   NS_HANDLER
   {
-    NSLog(@"Error! A fatal error occured while detaching the thread.");
+    NSLog(@"Error! A fatal error occurred while detaching the thread.");
   }
   NS_ENDHANDLER
 }
@@ -493,7 +509,7 @@ static GWDesktopManager *desktopManager = nil;
 
   if ([dskNode isValid] == NO) {
     NSRunAlertPanel(nil, 
-                    NSLocalizedString(@"The Desktop directory has been deleted! Quiting now!", @""), 
+                    NSLocalizedString(@"The Desktop directory has been deleted! Quitting now!", @""),
                     NSLocalizedString(@"OK", @""), 
                     nil, 
                     nil);                                     
@@ -523,7 +539,7 @@ static GWDesktopManager *desktopManager = nil;
       if ([event isEqual: @"GWWatchedPathDeleted"])
         {
           NSRunAlertPanel(nil, 
-                          NSLocalizedString(@"The Desktop directory has been deleted! Quiting now!", @""), 
+                          NSLocalizedString(@"The Desktop directory has been deleted! Quitting now!", @""),
                           NSLocalizedString(@"OK", @""), 
                           nil, 
                           nil);                                     
@@ -611,6 +627,8 @@ static GWDesktopManager *desktopManager = nil;
   [defaults setObject: [NSNumber numberWithInt: dockPosition]
                forKey: @"dockposition"];
 
+  [defaults setBool: singleClickLaunch forKey: @"singleclicklaunch"];
+
   [defaults setBool: usexbundle forKey: @"xbundle"];
   [defaults setBool: hidedock forKey: @"hidedock"];
   
@@ -747,7 +765,7 @@ static GWDesktopManager *desktopManager = nil;
 - (void)openSelectionAsFolder
 {
   NSArray *selnodes = [desktopView selectedNodes];
-  int i;
+  unsigned i;
     
   for (i = 0; i < [selnodes count]; i++) {
     FSNode *node = [selnodes objectAtIndex: i];
@@ -851,7 +869,7 @@ static GWDesktopManager *desktopManager = nil;
 
 - (void)selectAllInViewer
 {
-	[desktopView selectAll];
+  [desktopView selectAll];
 }
 
 - (void)showTerminal
@@ -866,97 +884,84 @@ static GWDesktopManager *desktopManager = nil;
 
 - (void)dealloc
 {
-	if (timer && [timer isValid]) {
-		[timer invalidate];
-	}  
-  RELEASE (volinfo);  
-	[super dealloc];
+  if (timer && [timer isValid])
+    {
+      [timer invalidate];
+    }
+
+  RELEASE (mountedRemovableVolumes);
+  [super dealloc];
 }
 
 - (id)initForManager:(GWDesktopManager *)mngr
 {
   self = [super init];
   
-  if (self) {
-    manager = mngr;    
-    volinfo = [NSMutableArray new];
-    active = NO;
-    fm = [NSFileManager defaultManager];
-    
-    timer = [NSTimer scheduledTimerWithTimeInterval: 1.0 
-												                     target: self 
-                                           selector: @selector(watchMountPoints:) 
-										                       userInfo: nil 
-                                            repeats: YES];
-  }
+  if (self)
+    {
+      manager = mngr;
+      active = NO;
+      fm = [NSFileManager defaultManager];
+
+      timer = [NSTimer scheduledTimerWithTimeInterval: 1.5
+					       target: self
+					     selector: @selector(watchMountPoints:)
+					     userInfo: nil
+					      repeats: YES];
+    }
   
   return self;
 }
 
 - (void)startWatching
 {
-  NSSet *volumes = [[FSNodeRep sharedInstance] volumes];
-  NSEnumerator *enumerator = [volumes objectEnumerator];
-  NSString *path;
-  
-  [volinfo removeAllObjects];
-
-  while ((path = [enumerator nextObject])) {
-    NSDictionary *attributes = [fm fileAttributesAtPath: path traverseLink: NO];
-    
-    if (attributes) {
-      NSDate *moddate = [attributes fileModificationDate];
-      NSMutableDictionary *dict = [NSMutableDictionary dictionary];
-      
-      [dict setObject: path forKey: @"path"];
-      [dict setObject: moddate forKey: @"moddate"];
-      
-      [volinfo addObject: dict];  
-    }
-  }
-
+  [mountedRemovableVolumes release];
+  mountedRemovableVolumes = [[NSWorkspace sharedWorkspace] mountedRemovableMedia];
+  [mountedRemovableVolumes retain];
   active = YES;
 }
 
 - (void)stopWatching
 {
   active = NO;
-  [volinfo removeAllObjects];
+  [mountedRemovableVolumes release];
+  mountedRemovableVolumes = nil;
 }
 
 - (void)watchMountPoints:(id)sender
 {
-  if (active) {
-    int count = [volinfo count];
-    BOOL changed = NO;
-    NSUInteger i;
-    
-    for (i = 0; i < count; i++) {
-      NSMutableDictionary *dict = [volinfo objectAtIndex: i];
-      NSString *path = [dict objectForKey: @"path"];
-      NSDate *moddate = [dict objectForKey: @"moddate"];
-      NSDictionary *attributes = [fm fileAttributesAtPath: path traverseLink: NO];      
-      
-      if (attributes) {
-        NSDate *lastmod = [attributes fileModificationDate];
-      
-        if ([moddate isEqualToDate: lastmod] == NO) {
-          [dict setObject: lastmod forKey: @"moddate"];
-          changed = YES;
-        }
-        
-      } else {
-        [volinfo removeObjectAtIndex: i]; 
-        count--;
-        i--;
-        changed = YES;       
-      }      
+  if (active)
+    {
+      BOOL removed = NO;
+      BOOL added = NO;
+      NSUInteger i;
+      NSArray *newVolumes = [[NSWorkspace sharedWorkspace] mountedRemovableMedia];
+
+      for (i = 0; i < [mountedRemovableVolumes count]; i++)
+	{
+	  NSString *vol;
+
+	  vol = [mountedRemovableVolumes objectAtIndex:i];
+	  if (![newVolumes containsObject:vol])
+	    removed |= YES;
+	}
+
+      for (i = 0; i < [newVolumes count]; i++)
+	{
+	  NSString *vol;
+
+	  vol = [newVolumes objectAtIndex:i];
+	  if (![mountedRemovableVolumes containsObject:vol])
+	    added |= YES;
+	}
+
+      if (added || removed)
+	[manager mountedVolumesDidChange];
+
+      [mountedRemovableVolumes release];
+      mountedRemovableVolumes = newVolumes;
+      [mountedRemovableVolumes retain];
     }
-    
-    if (changed) {
-      [manager mountedVolumesDidChange]; 
-    }
-  }
 }
 
 @end
@@ -972,6 +977,3 @@ static GWDesktopManager *desktopManager = nil;
 }
 
 @end
-
-
-
