@@ -1,6 +1,6 @@
 /* GWDesktopView.m
  *  
- * Copyright (C) 2005-2016 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2018 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  *         Riccardo Mottola <rm@gnu.org>
@@ -154,38 +154,53 @@
 
 - (void)showMountedVolumes
 {
-  NSArray *rvpaths = [[NSWorkspace sharedWorkspace] mountedRemovableMedia];
+  NSArray *rvPaths;
+  NSMutableArray *newVolumes;
+  NSUInteger i;
+  BOOL added;
 
-  if ([mountedVolumes isEqual: rvpaths] == NO) {
-    int count = [icons count];
-    int i;
-        
-    [mountedVolumes removeAllObjects];
-    [mountedVolumes addObjectsFromArray: rvpaths];
+  added = NO;
 
-    for (i = 0; i < count; i++) {
-      FSNIcon *icon = [icons objectAtIndex: i];
+  rvPaths = [[NSWorkspace sharedWorkspace] mountedRemovableMedia];
+  newVolumes = [NSMutableArray arrayWithCapacity:1];
 
-      if ([[icon node] isMountPoint]) {
-        [self removeRep: icon];
-        count--;
-        i--;
-      }
+  for (i = 0; i < [mountedVolumes count]; i++)
+    {
+      NSString *v;
+
+      v = [mountedVolumes objectAtIndex:i];
+      if ([rvPaths indexOfObject:v] == NSNotFound)
+	{
+	  NSLog(@"removing: %@", v);
+	  [mountedVolumes removeObjectAtIndex:i];
+	  [self workspaceDidUnmountVolumeAtPath: v];
+	}
     }
 
-    for (i = 0; i < [mountedVolumes count]; i++) {
-      NSString *vpath = [mountedVolumes objectAtIndex: i];
+  for (i = 0; i < [rvPaths count]; i++)
+    {
+      NSString *v;
 
-      if ([vpath isEqual: path_separator()] == NO) {
-        FSNode *vnode = [FSNode nodeWithPath: vpath];
-
-        [vnode setMountPoint: YES];
-        [self addRepForSubnode: vnode];
-      }
+      v = [rvPaths objectAtIndex:i];
+      if ([mountedVolumes indexOfObject:v] == NSNotFound)
+	{
+	  [newVolumes addObject:v];
+	  if ([v isEqual: path_separator()] == NO)
+	    {
+	      NSLog(@"new volume: %@", v);
+	      [self newVolumeMountedAtPath:v];
+	    }
+	  added = YES;
+	}
     }
 
-    [self tile];  
-  }
+  // we add new volumes at once at the end, or we disturb our for cycle
+  // we Tile only when adding, since workspaceDidUnmountVolumeAtPath does it for us
+  if (added)
+    {
+      [mountedVolumes addObjectsFromArray:newVolumes];
+      [self tile];
+    }
 }
 
 - (void)dockPositionDidChange
@@ -197,7 +212,7 @@
 
 - (void)tile
 {
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [icons count]; i++) {
     FSNIcon *icon = [icons objectAtIndex: i];
@@ -251,47 +266,48 @@
     }
   } 
   
-	return -1;
+  return -1;
 }
 
 - (BOOL)isFreeGridIndex:(int)index
 {
-	int i;
+  NSUInteger i;
 	
-  if ((index < 0) || (index >= gridcount)) {
+  if ((index < 0) || (index >= gridcount))
     return NO;
-  }
   
-	for (i = 0; i < [icons count]; i++) {
-		if ([[icons objectAtIndex: i] gridIndex] == index) {
-			return NO;
-		}
-  }
+  for (i = 0; i < [icons count]; i++)
+    {
+      if ([[icons objectAtIndex: i] gridIndex] == index) {
+	return NO;
+      }
+    }
   
-	return YES;
+  return YES;
 }
 
-- (FSNIcon *)iconWithGridIndex:(int)index
+- (FSNIcon *)iconWithGridIndex:(NSUInteger)index
 {
-	int i;
+  NSUInteger i;
 	
-	for (i = 0; i < [icons count]; i++) {
-    FSNIcon *icon = [icons objectAtIndex: i];
-    
-		if ([icon gridIndex] == index) {
-			return icon;
-		}
-  }
+  for (i = 0; i < [icons count]; i++)
+    {
+      FSNIcon *icon = [icons objectAtIndex: i];
+      
+      if ([icon gridIndex] == index) {
+	return icon;
+      }
+    }
   
-	return nil;
+  return nil;
 }
 
 - (NSArray *)iconsWithGridOriginX:(float)x
 {
   NSMutableArray *icns = [NSMutableArray array];
-  int i;
+  NSUInteger i;
   
-	for (i = 0; i < [icons count]; i++) {
+  for (i = 0; i < [icons count]; i++) {
     FSNIcon *icon = [icons objectAtIndex: i];
     NSPoint p = [icon frame].origin;
     
@@ -376,13 +392,13 @@
   NSRect tshfr = [manager tshelfReservedFrame];
   NSRect mmfr = [manager macmenuReservedFrame];
   NSRect gridrect = screenFrame;
-  int ymargin;
+  unsigned ymargin;
   NSPoint gpnt;
-  int i;
+  unsigned i;
   
-	if (grid != NULL) {
-		NSZoneFree (NSDefaultMallocZone(), grid);
-	}
+  if (grid != NULL) {
+    NSZoneFree (NSDefaultMallocZone(), grid);
+  }
   
   [self calculateGridSize];
   
@@ -404,9 +420,9 @@
   
   colcount = (int)(gridrect.size.width / (gridSize.width + X_MARGIN));  
   rowcount = (int)(gridrect.size.height / (gridSize.height + ymargin));
-	gridcount = colcount * rowcount;
+  gridcount = colcount * rowcount;
 
-	grid = NSZoneMalloc (NSDefaultMallocZone(), sizeof(NSRect) * gridcount);	
+  grid = NSZoneMalloc (NSDefaultMallocZone(), sizeof(NSRect) * gridcount);	
     
   gpnt.x = gridrect.size.width + gridrect.origin.x;
   gpnt.y = gridrect.size.height + gridrect.origin.y;
@@ -574,7 +590,7 @@
   NSColor *tempColor;
   NSMutableDictionary *backColorDict = [NSMutableDictionary dictionary];
   CGFloat red, green, blue, alpha;
-  int i;
+  NSUInteger i;
 
   tempColor = [backColor colorUsingColorSpaceName: NSCalibratedRGBColorSpace];
   [tempColor getRed: &red green: &green blue: &blue alpha: &alpha];
@@ -625,13 +641,14 @@
 
 - (void)selectIconInPrevLine
 {
-	int i;
+  NSUInteger i;
   
-	for (i = 0; i < [icons count]; i++) {
-		FSNIcon *icon = [icons objectAtIndex: i];
-    int index = [icon gridIndex];
+  for (i = 0; i < [icons count]; i++)
+    {
+      FSNIcon *icon = [icons objectAtIndex: i];
+      int index = [icon gridIndex];
     
-		if ([icon isSelected]) {
+      if ([icon isSelected]) {
       FSNIcon *prev;
       
       while (index > 0) {
@@ -652,9 +669,10 @@
 
 - (void)selectIconInNextLine
 {
-	int i;
+  NSUInteger i;
   
-	for (i = 0; i < [icons count]; i++) {
+  for (i = 0; i < [icons count]; i++)
+    {
 		FSNIcon *icon = [icons objectAtIndex: i];
     int index = [icon gridIndex];
     
@@ -1693,7 +1711,7 @@ static void GWHighlightFrameRect(NSRect aRect)
 	return YES;
 }
 
-int sortDragged(id icn1, id icn2, void *context)
+NSComparisonResult sortDragged(id icn1, id icn2, void *context)
 {
   NSArray *indexes = (NSArray *)context;
   int pos1 = [icn1 gridIndex];
@@ -1778,7 +1796,7 @@ int sortDragged(id icn1, id icn2, void *context)
       firstinrow++;
     }
 
-    sorted = [removed sortedArrayUsingFunction: (int (*)(id, id, void *))sortDragged 
+    sorted = [removed sortedArrayUsingFunction: sortDragged
                                        context: (void *)sortIndexes];
 
     for (i = 0; i < [sorted count]; i++) {
