@@ -1,6 +1,6 @@
 /* GWViewer.m
  *  
- * Copyright (C) 2004-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2015 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  *         Riccardo Mottola
@@ -43,6 +43,7 @@
 #import "FSNodeRep.h"
 #import "FSNIcon.h"
 #import "FSNFunctions.h"
+#import "Thumbnailer/GWThumbnailer.h"
 
 #define DEFAULT_INCR 150
 #define MIN_WIN_H 300
@@ -63,10 +64,9 @@
   RELEASE (baseNode);
   RELEASE (baseNodeArray);
   RELEASE (lastSelection);
-  RELEASE (rootViewerKey);
+  RELEASE (defaultsKeyStr);
   RELEASE (watchedNodes);
   RELEASE (vwrwin);
-  RELEASE (viewType);
   RELEASE (viewerPrefs);
   RELEASE (history);
   
@@ -75,8 +75,9 @@
 
 - (id)initForNode:(FSNode *)node
          inWindow:(GWViewerWindow *)win
-         showType:(NSString *)stype
+         showType:(GWViewType)stype
     showSelection:(BOOL)showsel
+	  withKey:(NSString *)key
 {
   self = [super init];
   
@@ -85,6 +86,7 @@
     NSString *prefsname;
     id defEntry;
     NSRect r;
+    NSString *viewTypeStr;
         
     ASSIGN (baseNode, [FSNode nodeWithPath: [node path]]);
     ASSIGN (baseNodeArray, [NSArray arrayWithObject: baseNode]);
@@ -104,27 +106,38 @@
       resizeIncrement = DEFAULT_INCR;
     }
     
-    rootviewer = ([[baseNode path] isEqual: path_separator()]
-                && ([[manager viewersForBaseNode: baseNode] count] == 0));
+    rootViewer = [[baseNode path] isEqual: path_separator()];
+    firstRootViewer = (rootViewer && ([[manager viewersForBaseNode: baseNode] count] == 0));
     
-    if ((rootviewer == NO) && [[baseNode path] isEqual: path_separator()]) {
-      rootViewerKey = [manager nextRootViewerKey];
-      
-      if (rootViewerKey == nil) {
-        ASSIGN (rootViewerKey, [NSNumber numberWithUnsignedLong: (unsigned long)self]);
-      } else {
-        RETAIN (rootViewerKey);
-      }
-      
-      prefsname = [NSString stringWithFormat: @"viewer_at_%@_%u", 
-                            [node path], [rootViewerKey unsignedLongValue]];
+    if (rootViewer == YES)
+      {
+	if (firstRootViewer)
+	  {
+	    prefsname = @"root_viewer";
+	  }
+	else
+	  {
+	    if (key == nil)
+	      {
+		NSNumber *rootViewerKey;
 
-    } else {
-      rootViewerKey = nil;
-      prefsname = [NSString stringWithFormat: @"viewer_at_%@", [node path]];
-    }
-    
-    if ([baseNode isWritable] && (rootviewer == NO) && (rootViewerKey == nil)
+		rootViewerKey = [NSNumber numberWithUnsignedLong: (unsigned long)self];
+
+		prefsname = [NSString stringWithFormat: @"%lu_viewer_at_%@", [rootViewerKey unsignedLongValue], [node path]];
+	      }
+	    else
+	      {
+		prefsname = [key retain];
+	      }
+	  }
+      }
+    else
+      {
+	prefsname = [NSString stringWithFormat: @"viewer_at_%@", [node path]];
+      }
+
+    defaultsKeyStr = [prefsname retain];
+    if ([baseNode isWritable] && (rootViewer == NO)
             && ([[fsnodeRep volumes] containsObject: [baseNode path]] == NO)) {
 		  NSString *dictPath = [[baseNode path] stringByAppendingPathComponent: @".gwdir"];
 
@@ -138,8 +151,7 @@
     }
     
     if (viewerPrefs == nil) {
-      defEntry = [defaults dictionaryForKey: prefsname];
-      NSLog(@"prfsname %@", defEntry);
+      defEntry = [defaults dictionaryForKey: defaultsKeyStr];
       if (defEntry) {
         viewerPrefs = [defEntry copy];
       } else {
@@ -147,25 +159,29 @@
       }
     }
     
-    viewType = [viewerPrefs objectForKey: @"viewtype"];
-    NSLog(@"viewtype: %@", viewType);
-    if (viewType == nil) {
-      if (stype != nil) {
-        viewType = stype;
-      } else {
-        viewType = @"Browser";
+    viewType = GWViewTypeBrowser;
+    viewTypeStr = [viewerPrefs objectForKey: @"viewtype"];
+    if (viewTypeStr == nil)
+      {
+        if (stype != 0)
+          {
+            viewType = stype;
+          }
+      }
+    else if ([viewTypeStr isEqual: @"Browser"])
+      {
+        viewType = GWViewTypeBrowser;
+      }
+    else if ([viewTypeStr isEqual: @"List"])
+      {
+        viewType = GWViewTypeList;
+      }
+    else if ([viewTypeStr isEqual: @"Icon"])
+      {
+        viewType = GWViewTypeIcon;
       }
-    }
-    if (([viewType isEqual: @"Icon"] == NO)
-              && ([viewType isEqual: @"List"] == NO)
-              && ([viewType isEqual: @"Browser"] == NO)) {
-      viewType = @"Browser";
-    }
-
-    RETAIN (viewType);
     
     defEntry = [viewerPrefs objectForKey: @"shelfheight"];
-    NSLog(@"height: %@", defEntry);
     if (defEntry) {
       shelfHeight = [defEntry floatValue];
     } else {
@@ -176,7 +192,6 @@
     [vwrwin setDelegate: self];
 
     defEntry = [viewerPrefs objectForKey: @"geometry"];
-    NSLog(@"geometry: %@", defEntry);
     if (defEntry) {
       [vwrwin setFrameFromString: defEntry];
     } else {
@@ -201,10 +216,10 @@
     [vwrwin setMinSize: NSMakeSize(resizeIncrement * 2, MIN_WIN_H)];    
     [vwrwin setResizeIncrements: NSMakeSize(resizeIncrement, 1)];
 
-    if (rootviewer) {
+    if (firstRootViewer) {
       [vwrwin setTitle: NSLocalizedString(@"File Viewer", @"")];
     } else {
-      if (rootViewerKey == nil) {   
+      if (rootViewer) {   
         [vwrwin setTitle: [NSString stringWithFormat: @"%@ - %@", [node name], [node parentPath]]];   
       } else {
         [vwrwin setTitle: [NSString stringWithFormat: @"%@", [node name]]];   
@@ -217,7 +232,7 @@
 
     if (defEntry && [defEntry count]) {
       [shelf setContents: defEntry];
-    } else if (rootviewer || rootViewerKey) {
+    } else if (rootViewer) {
       NSDictionary *sfdict = [NSDictionary dictionaryWithObjectsAndKeys:
                         [NSNumber numberWithInt: 0], @"index", 
                         [NSArray arrayWithObject: NSHomeDirectory()], @"paths", 
@@ -225,19 +240,19 @@
       [shelf setContents: [NSArray arrayWithObject: sfdict]];
     }
     
-    if ([viewType isEqual: @"Icon"]) {
+    if (viewType == GWViewTypeIcon) {
       nodeView = [[GWViewerIconsView alloc] initForViewer: self];
       
       [pathsScroll setDelegate: pathsView];
       
-    } else if ([viewType isEqual: @"List"]) { 
+    } else if (viewType == GWViewTypeList) { 
       NSRect r = [[nviewScroll contentView] bounds];
       
       nodeView = [[GWViewerListView alloc] initWithFrame: r forViewer: self];
        
       [pathsScroll setDelegate: pathsView];
        
-    } else if ([viewType isEqual: @"Browser"]) {    
+    } else if (viewType == GWViewTypeBrowser ) {    
       nodeView = [[GWViewerBrowser alloc] initWithBaseNode: baseNode
                                       inViewer: self
 		                            visibleColumns: visibleCols
@@ -308,7 +323,7 @@
 {
   NSRect r = [[vwrwin contentView] bounds];
   CGFloat w = r.size.width;
-	float h = r.size.height;   
+  CGFloat h = r.size.height;   
   CGFloat d = 0.0;
   int xmargin = 8;
   int ymargin = 6;
@@ -355,7 +370,7 @@
   r = [[pathsScroll contentView] bounds];
   pathsView = [[GWViewerIconsPath alloc] initWithFrame: r 
                    visibleIcons: visibleCols forViewer: self
-                   ownsScroller: ([viewType isEqual: @"Browser"] == NO)];
+                   ownsScroller: (viewType != GWViewTypeBrowser)];
   resizeMask = NSViewNotSizable;
   [pathsView setAutoresizingMask: resizeMask];
   [pathsScroll setDocumentView: pathsView];
@@ -364,7 +379,7 @@
   r = NSMakeRect(xmargin, 0, w - (xmargin * 2), h - pathscrh - ymargin);
   nviewScroll = [[GWViewerScrollView alloc] initWithFrame: r inViewer: self];
   [nviewScroll setBorderType: NSBezelBorder];
-  hasScroller = ([viewType isEqual: @"Icon"] || [viewType isEqual: @"List"]);
+  hasScroller = ((viewType ==GWViewTypeIcon) || (viewType ==GWViewTypeList));
   [nviewScroll setHasHorizontalScroller: hasScroller];
   [nviewScroll setHasVerticalScroller: hasScroller];
   resizeMask = NSViewNotSizable | NSViewWidthSizable | NSViewHeightSizable;
@@ -434,29 +449,19 @@
   return shelf;
 }
 
-- (NSString *)viewType
+- (GWViewType)viewType
 {
   return viewType;
 }
 
-- (BOOL)isRootViewer
+- (BOOL)isFirstRootViewer
 {
-  return rootviewer;
+  return firstRootViewer;
 }
 
-- (NSNumber *)rootViewerKey
+- (NSString *)defaultsKey
 {
-  return rootViewerKey;
-}
-
-- (BOOL)isSpatial
-{
-  return NO;
-}
-
-- (int)vtype
-{
-  return BROWSING;
+  return defaultsKeyStr;
 }
 
 - (void)activate
@@ -529,9 +534,8 @@
   FSNode *node;
   NSArray *components;
 
-  if (closing) {
+  if (closing)
     return;
-  }
 
   [manager selectionChanged: newsel];
 
@@ -629,7 +633,7 @@
     if ([node isDirectory] && ([node isPackage] == NO)) {
       nodetoshow = node;
       
-      if ([viewType isEqual: @"Browser"] == NO) {
+      if (viewType != GWViewTypeBrowser) {
         selection = nil;
       } else {
         selection = [NSArray arrayWithObject: node];
@@ -720,21 +724,21 @@
       destination = [destination stringByDeletingLastPathComponent]; 
     }
 
-    if ([operation isEqual: @"NSWorkspaceMoveOperation"] 
-          || [operation isEqual: @"NSWorkspaceCopyOperation"]
-          || [operation isEqual: @"NSWorkspaceLinkOperation"]
-          || [operation isEqual: @"NSWorkspaceDuplicateOperation"]
+    if ([operation isEqual: NSWorkspaceMoveOperation] 
+          || [operation isEqual: NSWorkspaceCopyOperation]
+          || [operation isEqual: NSWorkspaceLinkOperation]
+          || [operation isEqual: NSWorkspaceDuplicateOperation]
           || [operation isEqual: @"GWorkspaceCreateDirOperation"]
           || [operation isEqual: @"GWorkspaceCreateFileOperation"]
-          || [operation isEqual: @"NSWorkspaceRecycleOperation"]
+          || [operation isEqual: NSWorkspaceRecycleOperation]
           || [operation isEqual: @"GWorkspaceRenameOperation"]
 			    || [operation isEqual: @"GWorkspaceRecycleOutOperation"]) { 
       [nodeView reloadFromNode: [FSNode nodeWithPath: destination]];
     }
 
-    if ([operation isEqual: @"NSWorkspaceMoveOperation"]
-          || [operation isEqual: @"NSWorkspaceDestroyOperation"]
-				  || [operation isEqual: @"NSWorkspaceRecycleOperation"]
+    if ([operation isEqual: NSWorkspaceMoveOperation]
+          || [operation isEqual: NSWorkspaceDestroyOperation]
+				  || [operation isEqual: NSWorkspaceRecycleOperation]
 				  || [operation isEqual: @"GWorkspaceRecycleOutOperation"]
 				  || [operation isEqual: @"GWorkspaceEmptyRecyclerOperation"]) {
       [nodeView reloadFromNode: [FSNode nodeWithPath: source]];
@@ -835,21 +839,27 @@
 
 - (void)updateDefaults
 {
-  if ([baseNode isValid]) {
-    NSMutableDictionary *updatedprefs = [nodeView updateNodeInfo: NO];
-    id defEntry;
+  if ([baseNode isValid])
+    {
+      NSMutableDictionary *updatedprefs = [nodeView updateNodeInfo: NO];
+      id defEntry;
+      NSString *viewTypeStr;
+
+      if (viewType == GWViewTypeIcon)
+        viewTypeStr = @"Icon";
+      else if (viewType == GWViewTypeList)
+        viewTypeStr = @"List";
+      else
+        viewTypeStr = @"Browser";
 
     if (updatedprefs == nil) {
       updatedprefs = [NSMutableDictionary dictionary];
     }
 
-    [updatedprefs setObject: [NSNumber numberWithBool: NO]
-                     forKey: @"spatial"];
-
     [updatedprefs setObject: [NSNumber numberWithBool: [nodeView isSingleNode]]
                      forKey: @"singlenode"];
 
-    [updatedprefs setObject: viewType forKey: @"viewtype"];
+    [updatedprefs setObject: viewTypeStr forKey: @"viewtype"];
 
     [updatedprefs setObject: [NSNumber numberWithFloat: shelfHeight]
                      forKey: @"shelfheight"];
@@ -870,23 +880,14 @@
 
     [baseNode checkWritable];
 
-    if ([baseNode isWritable] && (rootviewer == NO) && (rootViewerKey == nil)
+    if ([baseNode isWritable] && (rootViewer == NO)
               && ([[fsnodeRep volumes] containsObject: [baseNode path]] == NO)) {
       NSString *dictPath = [[baseNode path] stringByAppendingPathComponent: @".gwdir"];
 
       [updatedprefs writeToFile: dictPath atomically: YES];
     } else {
-      NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];	
-      NSString *prefsname;
-    
-      if (rootViewerKey != nil) {
-        prefsname = [NSString stringWithFormat: @"viewer_at_%@_%u", 
-                            [baseNode path], [rootViewerKey unsignedLongValue]];
-      } else {
-        prefsname = [NSString stringWithFormat: @"viewer_at_%@", [baseNode path]];
-      }
-    
-      [defaults setObject: updatedprefs forKey: prefsname];
+      NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];	    
+      [defaults setObject: updatedprefs forKey: defaultsKeyStr];
     }
     
     ASSIGN (viewerPrefs, [updatedprefs makeImmutableCopyOnFail: NO]);
@@ -960,16 +961,15 @@ constrainMinCoordinate:(CGFloat)proposedMin
 
 - (void)windowDidBecomeKey:(NSNotification *)aNotification
 {
-  NSArray *selection = [nodeView selectedNodes];  
-    
-  [vwrwin makeFirstResponder: nodeView];  
+  NSArray *selection = [nodeView selectedNodes];
 
-  if ([selection count] == 0) {
-    selection = [NSArray arrayWithObject: [nodeView shownNode]];
-  }
-  
   [manager updateDesktop];
+  if ([selection count] == 0)
+    {
+      selection = [NSArray arrayWithObject: [nodeView shownNode]];
+    }
   [self selectionChanged: selection];
+  
   [manager changeHistoryOwner: self];
 }
 
@@ -1024,12 +1024,12 @@ constrainMinCoordinate:(CGFloat)proposedMin
       NSMutableArray *dirs = [NSMutableArray array];
       NSUInteger i;
 
-      if (count > OPEN_MAX) {
+      if (count > MAX_FILES_TO_OPEN_DIALOG) {
         NSString *msg1 = NSLocalizedString(@"Are you sure you want to open", @"");
         NSString *msg2 = NSLocalizedString(@"items?", @"");
 
         if (NSRunAlertPanel(nil,
-                    [NSString stringWithFormat: @"%@ %i %@", msg1, count, msg2],
+                            [NSString stringWithFormat: @"%@ %lu %@", msg1, (unsigned long)count, msg2],
                     NSLocalizedString(@"Cancel", @""),
                     NSLocalizedString(@"Yes", @""),
                     nil)) {
@@ -1210,128 +1210,134 @@ constrainMinCoordinate:(CGFloat)proposedMin
   [manager goForwardInHistoryOfViewer: self];
 }
 
-- (void)setViewerBehaviour:(id)sender
-{
-  [manager setBehaviour: [sender title] forViewer: self];
-}
-
 - (void)setViewerType:(id)sender
 {
-  NSString *title = [sender title];
-  
-  if ([title isEqual: NSLocalizedString(viewType, @"")] == NO) {
-    NSArray *selection = [nodeView selectedNodes];
-    NSUInteger i;
+  NSInteger tag = [sender tag];
+
+  if (tag > 0)
+    {
+      NSArray *selection = [nodeView selectedNodes];
+      NSUInteger i;
     
-    [nodeView updateNodeInfo: YES];
-    if ([nodeView isSingleNode] && ([selection count] == 0)) {
-      selection = [NSArray arrayWithObject: [nodeView shownNode]];
-    }
-    RETAIN (selection);
+      [nodeView updateNodeInfo: YES];
+      if ([nodeView isSingleNode] && ([selection count] == 0))
+        selection = [NSArray arrayWithObject: [nodeView shownNode]];
+ 
+      RETAIN (selection);
     
-    [nviewScroll setDocumentView: nil];	
+      [nviewScroll setDocumentView: nil];	
     
-    if ([title isEqual: NSLocalizedString(@"Browser", @"")]) {
-      [pathsScroll setDelegate: nil];
-      [pathsView setOwnsScroller: NO];
+      if (tag == GWViewTypeBrowser)
+        {
+          [pathsScroll setDelegate: nil];
+          [pathsView setOwnsScroller: NO];
 
-      [nviewScroll setHasVerticalScroller: NO];
-      [nviewScroll setHasHorizontalScroller: NO];
+          [nviewScroll setHasVerticalScroller: NO];
+          [nviewScroll setHasHorizontalScroller: NO];
 
-      nodeView = [[GWViewerBrowser alloc] initWithBaseNode: baseNode
-                                      inViewer: self
-		                            visibleColumns: visibleCols
-                                      scroller: [pathsScroll horizontalScroller]
-                                    cellsIcons: NO
-                                 editableCells: NO
-                               selectionColumn: YES];
+          nodeView = [[GWViewerBrowser alloc] initWithBaseNode: baseNode
+                                                      inViewer: self
+                                                visibleColumns: visibleCols
+                                                      scroller: [pathsScroll horizontalScroller]
+                                                    cellsIcons: NO
+                                                 editableCells: NO
+                                               selectionColumn: YES];
       
-      ASSIGN (viewType, @"Browser");
-      
-    } else if ([title isEqual: NSLocalizedString(@"Icon", @"")]) {
-      NSScroller *scroller = RETAIN ([pathsScroll horizontalScroller]);
-
-      [pathsScroll setHasHorizontalScroller: NO];
-      [pathsScroll setHorizontalScroller: scroller]; 
-      [pathsScroll setHasHorizontalScroller: YES];
-      RELEASE (scroller);
-      
-      [pathsView setOwnsScroller: YES];
-      [pathsScroll setDelegate: pathsView];
-
-      [nviewScroll setHasVerticalScroller: YES];
-      [nviewScroll setHasHorizontalScroller: YES];
-   
-      nodeView = [[GWViewerIconsView alloc] initForViewer: self];
-      
-      ASSIGN (viewType, @"Icon");
-      
-    } else if ([title isEqual: NSLocalizedString(@"List", @"")]) {
-      NSRect r = [[nviewScroll contentView] bounds];
-
-      NSScroller *scroller = RETAIN ([pathsScroll horizontalScroller]);
-
-      [pathsScroll setHasHorizontalScroller: NO];
-      [pathsScroll setHorizontalScroller: scroller]; 
-      [pathsScroll setHasHorizontalScroller: YES];
-      RELEASE (scroller);
-      
-      [pathsView setOwnsScroller: YES];
-      [pathsScroll setDelegate: pathsView];
-
-      [nviewScroll setHasVerticalScroller: YES];
-      [nviewScroll setHasHorizontalScroller: YES];
-
-      nodeView = [[GWViewerListView alloc] initWithFrame: r forViewer: self];
-
-      ASSIGN (viewType, @"List");
-    }
-    
-    [nviewScroll setDocumentView: nodeView];	
-    RELEASE (nodeView); 
-    [nodeView showContentsOfNode: baseNode]; 
-                    
-    if ([selection count]) {
-      if ([nodeView isSingleNode]) {
-        FSNode *basend = [selection objectAtIndex: 0];
-        
-        if ([basend isEqual: baseNode] == NO) {
-          if (([selection count] > 1) 
-                || (([basend isDirectory] == NO) || ([basend isPackage]))) {            
-            basend = [FSNode nodeWithPath: [basend parentPath]];
-          }
+          viewType = GWViewTypeBrowser;
         }
+      else if (tag == GWViewTypeIcon)
+        {
+          NSScroller *scroller = RETAIN ([pathsScroll horizontalScroller]);
 
-        [nodeView showContentsOfNode: basend];
-        [nodeView selectRepsOfSubnodes: selection];
+          [pathsScroll setHasHorizontalScroller: NO];
+          [pathsScroll setHorizontalScroller: scroller]; 
+          [pathsScroll setHasHorizontalScroller: YES];
+          RELEASE (scroller);
+      
+          [pathsView setOwnsScroller: YES];
+          [pathsScroll setDelegate: pathsView];
 
-      } else {
-        [nodeView selectRepsOfSubnodes: selection];
-      }
+          [nviewScroll setHasVerticalScroller: YES];
+          [nviewScroll setHasHorizontalScroller: YES];
+   
+          nodeView = [[GWViewerIconsView alloc] initForViewer: self];
+      
+          viewType = GWViewTypeIcon;     
+        }
+      else if (tag == GWViewTypeList)
+        {
+          NSRect r = [[nviewScroll contentView] bounds];
+
+          NSScroller *scroller = RETAIN ([pathsScroll horizontalScroller]);
+
+          [pathsScroll setHasHorizontalScroller: NO];
+          [pathsScroll setHorizontalScroller: scroller]; 
+          [pathsScroll setHasHorizontalScroller: YES];
+          RELEASE (scroller);
+      
+          [pathsView setOwnsScroller: YES];
+          [pathsScroll setDelegate: pathsView];
+
+          [nviewScroll setHasVerticalScroller: YES];
+          [nviewScroll setHasHorizontalScroller: YES];
+
+          nodeView = [[GWViewerListView alloc] initWithFrame: r forViewer: self];
+
+          viewType = GWViewTypeList;
+        }
+    
+      [nviewScroll setDocumentView: nodeView];	
+      RELEASE (nodeView); 
+      [nodeView showContentsOfNode: baseNode]; 
+                    
+      if ([selection count])
+        {
+          if ([nodeView isSingleNode])
+            {
+              FSNode *basend = [selection objectAtIndex: 0];
+        
+              if ([basend isEqual: baseNode] == NO)
+                {
+                  if (([selection count] > 1) || (([basend isDirectory] == NO) || ([basend isPackage])))
+                    {
+                      basend = [FSNode nodeWithPath: [basend parentPath]];
+                    }
+                }
+              
+              [nodeView showContentsOfNode: basend];
+              [nodeView selectRepsOfSubnodes: selection];
+              
+            }
+          else
+            {
+              [nodeView selectRepsOfSubnodes: selection];
+            }
+        }
+      
+      DESTROY (selection);
+    
+      [self scrollToBeginning];
+
+      [vwrwin makeFirstResponder: nodeView]; 
+
+      for (i = 0; i < [watchedNodes count]; i++)
+        {  
+          [gworkspace removeWatcherForPath: [[watchedNodes objectAtIndex: i] path]];
+        }
+      [watchedNodes removeAllObjects];
+      
+      DESTROY (lastSelection);
+      selection = [nodeView selectedNodes];
+      
+      if ([selection count] == 0)
+        {
+          selection = [NSArray arrayWithObject: [nodeView shownNode]];
+        }
+      
+      [self selectionChanged: selection];
+      
+      [self updateDefaults];
     }
-    
-    DESTROY (selection);
-    
-    [self scrollToBeginning];
-
-    [vwrwin makeFirstResponder: nodeView]; 
-
-    for (i = 0; i < [watchedNodes count]; i++) {  
-      [gworkspace removeWatcherForPath: [[watchedNodes objectAtIndex: i] path]];
-    }
-    [watchedNodes removeAllObjects];
-    
-    DESTROY (lastSelection);
-    selection = [nodeView selectedNodes];
-    
-    if ([selection count] == 0) {
-      selection = [NSArray arrayWithObject: [nodeView shownNode]];
-    }
-    
-    [self selectionChanged: selection];
-    
-    [self updateDefaults];
-  }
 }
 
 - (void)setShownType:(id)sender
@@ -1477,7 +1483,10 @@ constrainMinCoordinate:(CGFloat)proposedMin
       }
 
       return NO;
-
+    } else if (sel_isEqual(action, @selector(makeThumbnails:)) || sel_isEqual(action, @selector(removeThumbnails:)))
+      {
+        /* Make or Remove Thumbnails */
+        return YES;
     } else if (sel_isEqual(action, @selector(openSelection:))) {
       if ([[baseNode path] isEqual: [gworkspace trashPath]] == NO) {
         BOOL canopen = YES;
@@ -1550,6 +1559,38 @@ constrainMinCoordinate:(CGFloat)proposedMin
   return NO;
 }
 
+- (void)makeThumbnails:(id)sender
+{
+  NSString *path;
+
+  path = [[nodeView shownNode] path];
+  path = [path stringByResolvingSymlinksInPath];
+  if (path)
+    {
+      Thumbnailer *t;
+      
+      t = [Thumbnailer sharedThumbnailer];
+      [t makeThumbnails:path];
+      [t release];
+    }
+}
+
+- (void)removeThumbnails:(id)sender
+{
+  NSString *path;
+
+  path = [[nodeView shownNode] path];
+  path = [path stringByResolvingSymlinksInPath];
+  if (path)
+    {
+      Thumbnailer *t;
+      
+      t = [Thumbnailer sharedThumbnailer];
+      [t removeThumbnails:path];
+      [t release];
+    }
+}
+
 @end
 
 
