@@ -1,6 +1,6 @@
 /* GWViewerListView.h
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: December 2004
@@ -22,11 +22,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#ifndef GW_VIEWER_LIST_VIEW_H
-#define GW_VIEWER_LIST_VIEW_H
 
-#include <Foundation/Foundation.h>
-#include "FSNListView.h"
+#import <Foundation/Foundation.h>
+#import "FSNListView.h"
 
 @class GWViewersManager;
 
@@ -51,5 +49,3 @@
           forViewer:(id)vwr;
 
 @end
-
-#endif // GW_VIEWER_LIST_VIEW_H
