@@ -1,6 +1,6 @@
 /* GWViewerShelf.h
  *  
- * Copyright (C) 2004-2012 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: July 2004
@@ -376,7 +376,7 @@
     highlightSize.height = iconSize + 4;
   }
 
-  labelSize.height = myrintf([fsnodeRep heighOfFont: labelFont]);
+  labelSize.height = myrintf([fsnodeRep heightOfFont: labelFont]);
   labelSize.width = gridSize.width;
   gridSize.height = highlightSize.height + labelSize.height;
 }
@@ -501,7 +501,7 @@
   hlightRect.size.width = ceil(iconSize / 3 * 4);
   hlightRect.size.height = ceil(hlightRect.size.width * [fsnodeRep highlightHeightFactor]);
   hlightRect.origin.x = ceil((gridSize.width - hlightRect.size.width) / 2);   
-  hlightRect.origin.y = floor([fsnodeRep heighOfFont: labelFont]);
+  hlightRect.origin.y = floor([fsnodeRep heightOfFont: labelFont]);
   
   icnBounds.origin.x += hlightRect.origin.x + ((hlightRect.size.width - iconSize) / 2);
   icnBounds.origin.y += hlightRect.origin.y + ((hlightRect.size.height - iconSize) / 2);
@@ -512,13 +512,13 @@
 - (void)tile
 {
   NSArray *subviews = [self subviews];
-  int i;
+  NSUInteger i;
 
   [self makeIconsGrid];
   
   for (i = 0; i < [icons count]; i++) {
     FSNIcon *icon = [icons objectAtIndex: i];
-    int index = [icon gridIndex];
+    NSUInteger index = [icon gridIndex];
     
     if (index < gridcount) {
       if ([subviews containsObject: icon] == NO) {
@@ -824,7 +824,7 @@
   NSArray *files = [info objectForKey: @"files"];
   int i;
 
-  if ([operation isEqual: @"NSWorkspaceRecycleOperation"]) {
+  if ([operation isEqual: NSWorkspaceRecycleOperation]) {
 		files = [info objectForKey: @"origfiles"];
   }	
   
@@ -846,12 +846,12 @@
     source = [source stringByDeletingLastPathComponent];
   }	
 
-  if ([operation isEqual: @"NSWorkspaceMoveOperation"] 
-        || [operation isEqual: @"NSWorkspaceDestroyOperation"]
-				|| [operation isEqual: @"GWorkspaceRenameOperation"]
-				|| [operation isEqual: @"NSWorkspaceRecycleOperation"]
-				|| [operation isEqual: @"GWorkspaceRecycleOutOperation"]
-				|| [operation isEqual: @"GWorkspaceEmptyRecyclerOperation"]) {
+  if ([operation isEqual: NSWorkspaceMoveOperation] 
+      || [operation isEqual: NSWorkspaceDestroyOperation]
+      || [operation isEqual: @"GWorkspaceRenameOperation"]
+      || [operation isEqual: NSWorkspaceRecycleOperation]
+      || [operation isEqual: @"GWorkspaceRecycleOutOperation"]
+      || [operation isEqual: @"GWorkspaceEmptyRecyclerOperation"]) {
     NSMutableArray *oppaths = [NSMutableArray array];
     int count = [icons count];
     BOOL updated = NO;
@@ -914,127 +914,149 @@
 - (void)watchedPathChanged:(NSDictionary *)info
 {
   NSString *path = [info objectForKey: @"path"];
-	NSString *event = [info objectForKey: @"event"];
-	NSEnumerator *enumerator;
+  NSString *event = [info objectForKey: @"event"];
+  NSEnumerator *enumerator;
   NSString *wpath;
   BOOL contained = NO;
-
-	if ([event isEqual: @"GWFileCreatedInWatchedDirectory"]) {
-		return;
-	}
+  
+  if ([event isEqual: @"GWFileCreatedInWatchedDirectory"])
+    {
+      return;
+    }
   
   enumerator = [watchedPaths objectEnumerator];
   
-	while ((wpath = [enumerator nextObject])) {
-		if (([wpath isEqual: path]) || (isSubpathOfPath(path, wpath))) {
-			contained = YES;
-			break;
-		}
-  }
+  while ((wpath = [enumerator nextObject]))
+    {
+      if (([wpath isEqual: path]) || (isSubpathOfPath(path, wpath)))
+        {
+          contained = YES;
+          break;
+        }
+    }
 
-  if (contained) {
-		int count = [icons count];
-    BOOL updated = NO;
-    FSNIcon *icon;
-	  int i;
+  if (contained)
+    {
+      NSUInteger count = [icons count];
+      BOOL updated = NO;
+      FSNIcon *icon;
+      NSUInteger i;
+      
+      if ([event isEqual: @"GWWatchedPathDeleted"])
+        {		
+          for (i = 0; i < count; i++)
+            {
+              icon = [icons objectAtIndex: i];
+              
+              if ([[icon node] isSubnodeOfPath: path])
+                {
+                  [self removeRep: icon];
+                  updated = YES;
+                  count--;
+                  i--;        
+                }
+            }
+          
+          if (updated)
+            {
+              [self tile];
+              [self setNeedsDisplay: YES];
+            }
+          
+          return;
+        }		
 
-		if ([event isEqual: @"GWWatchedPathDeleted"]) {		
-			for (i = 0; i < count; i++) {
-        icon = [icons objectAtIndex: i];
-        
-        if ([[icon node] isSubnodeOfPath: path]) {
-          [self removeRep: icon];
-          updated = YES;
-					count--;
-					i--;        
+      if ([event isEqual: @"GWFileDeletedInWatchedDirectory"])
+        { 
+          NSArray *files = [info objectForKey: @"files"];
+          
+          for (i = 0; i < count; i++)
+            {
+              NSUInteger j;
+				
+              icon = [icons objectAtIndex: i];
+
+              if ([icon isShowingSelection] == NO)
+                {
+                  FSNode *node = [icon node];
+                  
+                  for (j = 0; j < [files count]; j++)
+                    {
+                      NSString *fname = [files objectAtIndex: j];
+                      NSString *fpath = [path stringByAppendingPathComponent: fname];
+                      
+                      if ([[node path] isEqual: fpath] || [node isSubnodeOfPath: fpath])
+                        {
+                          [self removeRep: icon];
+                          updated = YES;
+                          count--;
+                          i--;
+                          break;
+                        }
+                    }
+                  
+                }
+              else
+                {
+                  FSNode *node = [icon node];
+                  NSArray *selection = [icon selection];
+                  
+                  for (j = 0; j < [files count]; j++)
+                    {
+                      NSString *fname = [files objectAtIndex: j];
+                      NSString *fpath = [path stringByAppendingPathComponent: fname];
+                      BOOL deleted = NO;
+                      NSUInteger m;
+                      
+                      if (deleted)
+                        {
+                          break;
+                        }
+
+                      if ([node isSubnodeOfPath: fpath])
+                        {
+                          [self removeRep: icon];
+                          updated = YES;
+                          count--;
+                          i--;
+                          break;
+                        }
+
+                      for (m = 0; m < [selection count]; m++)
+                        {
+                          node = [selection objectAtIndex: m];
+                          
+                          if ([[node path] isEqual: fpath])
+                            {
+                              [self removeRep: icon];
+                              updated = YES;
+                              count--;
+                              i--;			
+                              deleted = YES;
+                              break;	
+                            }
+                        }
+                    }
+                } 
+            }
+          
+          if (updated)
+            {
+              [self tile];
+              [self setNeedsDisplay: YES];
+            }
         }
-			}
-
-      if (updated) {
-        [self tile];
-        [self setNeedsDisplay: YES];
-      }
-      
-			return;
-		}		
-
-		if ([event isEqual: @"GWFileDeletedInWatchedDirectory"]) { 
-			NSArray *files = [info objectForKey: @"files"];
-
-			for (i = 0; i < count; i++) {
-				int j;
-				
-				icon = [icons objectAtIndex: i];
-
-        if ([icon isShowingSelection] == NO) {
-          FSNode *node = [icon node];
-
-	        for (j = 0; j < [files count]; j++) {
-						NSString *fname = [files objectAtIndex: j];
-						NSString *fpath = [path stringByAppendingPathComponent: fname];
-          
-            if ([[node path] isEqual: fpath] || [node isSubnodeOfPath: fpath]) {
-              [self removeRep: icon];
-              updated = YES;
-              count--;
-              i--;
-              break;
-            }
-          }
-          
-        } else {
-          FSNode *node = [icon node];
-          NSArray *selection = [icon selection];
-        
-	        for (j = 0; j < [files count]; j++) {
-						NSString *fname = [files objectAtIndex: j];
-						NSString *fpath = [path stringByAppendingPathComponent: fname];
-						BOOL deleted = NO;
-						int m;
-        
-						if (deleted) {
-							break;
-						}
-
-						if ([node isSubnodeOfPath: fpath]) {
-							[self removeRep: icon];
-              updated = YES;
-							count--;
-							i--;
-							break;
-						}
-
-            for (m = 0; m < [selection count]; m++) {
-              node = [selection objectAtIndex: m];
-        
-              if ([[node path] isEqual: fpath]) {
-								[self removeRep: icon];
-                updated = YES;
-								count--;
-								i--;			
-								deleted = YES;
-								break;	
-              }
-            }
-          }
-        } 
-      }
-  
-      if (updated) {
-        [self tile];
-        [self setNeedsDisplay: YES];
-      }
     }
-  }
 }
 
 - (void)checkLockedReps
 {
-  int i;
+  NSUInteger i;
   
-  for (i = 0; i < [icons count]; i++) {
-    [[icons objectAtIndex: i] checkLocked];
-  }
+  for (i = 0; i < [icons count]; i++)
+    {
+      [[icons objectAtIndex: i] checkLocked];
+    }
 }
 
 - (FSNSelectionMask)selectionMask
@@ -1081,42 +1103,48 @@
 
 - (NSDragOperation)draggingEntered:(id <NSDraggingInfo>)sender
 {
-	NSPasteboard *pb = [sender draggingPasteboard];
+  NSPasteboard *pb = [sender draggingPasteboard];
   NSDragOperation sourceDragMask = [sender draggingSourceOperationMask];
 
   DESTROY (dragIcon);
   isDragTarget = NO;	
   dragLocalIcon = NO;    
 
-	if ((sourceDragMask == NSDragOperationCopy) 
-												|| (sourceDragMask == NSDragOperationLink)) {
-		return NSDragOperationNone;
-	}
-
-  if (pb && [[pb types] containsObject: NSFilenamesPboardType]) {
-    NSArray *sourcePaths = [pb propertyListForType: NSFilenamesPboardType]; 
-    int count = [sourcePaths count];
-    FSNode *baseNode = [viewer baseNode];
-    NSString *basePath;
-    int i;
-        
-	  if (count == 0) {
-		  return NSDragOperationNone;
-    } 
-
-    for (i = 0; i < count; i++) {
-      NSString *path = [sourcePaths objectAtIndex: i];
-    
-      if ([baseNode isParentOfPath: path] == NO) {
-        return NSDragOperationNone;
-      } 
-    }  
-    
-    basePath = [[sourcePaths objectAtIndex: 0] stringByDeletingLastPathComponent];
-    if ([basePath isEqual: [gworkspace trashPath]]) {
+  if ((sourceDragMask == NSDragOperationCopy) 
+      || (sourceDragMask == NSDragOperationLink))
+    {
       return NSDragOperationNone;
     }
-    
+  
+  if (pb && [[pb types] containsObject: NSFilenamesPboardType])
+    {
+      NSArray *sourcePaths = [pb propertyListForType: NSFilenamesPboardType]; 
+      NSUInteger count = [sourcePaths count];
+      FSNode *baseNode = [viewer baseNode];
+      NSString *basePath;
+      NSUInteger i;
+      
+      if (count == 0)
+        {
+          return NSDragOperationNone;
+        } 
+      
+      for (i = 0; i < count; i++)
+        {
+          NSString *path = [sourcePaths objectAtIndex: i];
+          
+          if ([baseNode isParentOfPath: path] == NO)
+            {
+              return NSDragOperationNone;
+            } 
+        }  
+      
+      basePath = [[sourcePaths objectAtIndex: 0] stringByDeletingLastPathComponent];
+      if ([basePath isEqual: [gworkspace trashPath]])
+        {
+          return NSDragOperationNone;
+        }
+      
     if (count == 1) {
       dragLocalIcon = ([self iconForPath: [sourcePaths objectAtIndex: 0]] != nil);
     } else {
