@@ -1,6 +1,6 @@
 /* LSFolder.m
  *  
- * Copyright (C) 2004-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2014 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: October 2004
@@ -233,7 +233,7 @@ BOOL isPathInResults(NSString *path, NSArray *results);
   NSString *cname;
   NSString *cmd;
 
-  cname = [NSString stringWithFormat: @"search_%i", (unsigned long)self];
+  cname = [NSString stringWithFormat: @"search_%lu", (unsigned long)self];
 
   if (conn == nil) {
     conn = [[NSConnection alloc] initWithReceivePort: (NSPort *)[NSPort port] 
@@ -354,8 +354,8 @@ BOOL isPathInResults(NSString *path, NSArray *results);
       [resultsView noteNumberOfRowsChanged];
     }
 
-    [elementsLabel setStringValue: [NSString stringWithFormat: @"%i %@", 
-                                          [foundObjects count], elementsStr]];
+    [elementsLabel setStringValue: [NSString stringWithFormat: @"%lu %@", 
+                                             (unsigned long)[foundObjects count], elementsStr]];
   } 
 
   RELEASE (pool);
@@ -365,8 +365,8 @@ BOOL isPathInResults(NSString *path, NSArray *results);
 {
   CREATE_AUTORELEASE_POOL(pool);
   [foundObjects removeObject: [FSNode nodeWithPath: path]];
-  [elementsLabel setStringValue: [NSString stringWithFormat: @"%i %@", 
-                                        [foundObjects count], elementsStr]];
+  [elementsLabel setStringValue: [NSString stringWithFormat: @"%lu %@", 
+                                           (unsigned long)[foundObjects count], elementsStr]];
   [resultsView noteNumberOfRowsChanged];
   [pathViewer showComponentsOfSelection: [self selectedObjects]];
   RELEASE (pool);
@@ -375,8 +375,8 @@ BOOL isPathInResults(NSString *path, NSArray *results);
 - (void)clearFoundPaths
 {
   [foundObjects removeAllObjects];
-  [elementsLabel setStringValue: [NSString stringWithFormat: @"%i %@", 
-                                        [foundObjects count], elementsStr]];
+  [elementsLabel setStringValue: [NSString stringWithFormat: @"%lu %@", 
+                                           (unsigned long)[foundObjects count], elementsStr]];
   [resultsView noteNumberOfRowsChanged];
   [pathViewer showComponentsOfSelection: nil];
 }
@@ -868,15 +868,16 @@ shouldMakeNewConnection:(NSConnection*)newConn
     destination = [destination stringByDeletingLastPathComponent]; 
   }
 
-  if ([operation isEqual: @"NSWorkspaceRecycleOperation"]) {
+  if ([operation isEqual: NSWorkspaceRecycleOperation]) {
 		files = [info objectForKey: @"origfiles"];
   }	
   
-  if ([operation isEqual: @"NSWorkspaceMoveOperation"] 
-        || [operation isEqual: @"NSWorkspaceDestroyOperation"]
-				|| [operation isEqual: @"NSWorkspaceRecycleOperation"]
-				|| [operation isEqual: @"GWorkspaceRecycleOutOperation"]
-				|| [operation isEqual: @"GWorkspaceEmptyRecyclerOperation"]) {
+  if ([operation isEqual: NSWorkspaceMoveOperation] 
+        || [operation isEqual: NSWorkspaceDestroyOperation]
+      || [operation isEqual: NSWorkspaceRecycleOperation]
+      || [operation isEqual: @"GWorkspaceRecycleOutOperation"]
+      || [operation isEqual: @"GWorkspaceEmptyRecyclerOperation"])
+    {
     for (i = 0; i < [files count]; i++) {
       NSString *fname = [files objectAtIndex: i];
       NSString *fullPath = [source stringByAppendingPathComponent: fname];
