@@ -1,8 +1,9 @@
 /* TShelfIcon.h
  *  
- * Copyright (C) 2003-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2003-2021 Free Software Foundation, Inc.
  *
- * Author: Enrico Sersale <enrico@imago.ro>
+ * Authors: Enrico Sersale <enrico@imago.ro>
+ *          Riccardo Mottola <rm@gnu.org>
  * Date: August 2001
  *
  * This file is part of the GNUstep GWorkspace application
@@ -27,6 +28,12 @@
 
 #import <Foundation/Foundation.h>
 #import <AppKit/NSView.h>
+#import <AppKit/NSDragging.h>
+
+#define ICON_SIZE 48
+
+#define CHECK_LOCK if (locked) return
+#define CHECK_LOCK_RET(x) if (locked) return x
 
 #define ONICON(p, s1, s2) ([self mouse: (p) \
 inRect: NSMakeRect(((int)(s1).width - (int)(s2).width) >> 1,\
@@ -37,61 +44,39 @@ inRect: NSMakeRect(((int)(s1).width - (int)(s2).width) >> 1,\
 @class NSTextField;
 @class NSImage;
 @class NSBezierPath;
-@class NSWorkspace;
 @class TShelfIconsView;
-@class FSNode;
-@class FSNodeRep;
-@class GWorkspace;
+
 
 @interface TShelfIcon : NSView
 {
-  NSMutableArray *paths;
   NSString *name;
-  NSString *hostname;
-  FSNode *node;
-  BOOL singlepath;
-  BOOL isRootIcon;	
-  BOOL isPakage;	
-  BOOL isSelect;
+
+  BOOL isSelected;
   BOOL locked;
   
   NSImage *icon;
   NSTextField *namelabel;  
   NSBezierPath *highlightPath;
   NSPoint position;
-  NSUInteger gridindex;
+  NSUInteger gridIndex;
   int labelWidth;
   NSTrackingRectTag trectTag;
   
   TShelfIconsView *tview;
   
-  FSNodeRep *fsnodeRep;
-  NSFileManager *fm;
-  GWorkspace *gw;
-  
-  int dragdelay;
+  int dragDelay;
   BOOL isDragTarget;
-  BOOL forceCopy;
+
   BOOL onSelf;
+  int minimumLaunchClicks;
 }
 
-- (id)initForPaths:(NSArray *)fpaths 
-       inIconsView:(TShelfIconsView *)aview;
-
-- (id)initForPaths:(NSArray *)fpaths 
-        atPosition:(NSPoint)pos
-       inIconsView:(TShelfIconsView *)aview;
-
-- (id)initForPaths:(NSArray *)fpaths 
-	 gridIndex:(NSUInteger)index
-       inIconsView:(TShelfIconsView *)aview;
-
-- (void)setPaths:(NSArray *)fpaths;
-
 - (void)select;
 
 - (void)unselect;
 
+- (NSImage *)icon;
+
 - (void)renewIcon;
 
 - (void)setLabelWidth;
@@ -104,22 +89,22 @@ inRect: NSMakeRect(((int)(s1).width - (int)(s2).width) >> 1,\
 
 - (void)setGridIndex:(NSUInteger)index;
 
-- (NSUInteger)gridindex;
+- (NSUInteger)gridIndex;
 
 - (NSTextField *)myLabel;
 
 - (NSString *)shownName;
 
-- (NSArray *)paths;
-
-- (BOOL)isSinglePath;
-
-- (BOOL)isSelect;
+- (BOOL)isSelected;
 
 - (void)setLocked:(BOOL)value;
 
 - (BOOL)isLocked;
 
+- (NSComparisonResult)iconCompare:(id)other;
+
+- (void)setSingleClickLaunch:(BOOL)value;
+
 @end
 
 @interface TShelfIcon (DraggingSource)
