@@ -1,8 +1,9 @@
 /* TShelfIconsView.m
  *  
- * Copyright (C) 2003-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2003-2021 Free Software Foundation, Inc.
  *
- * Author: Enrico Sersale <enrico@imago.ro>
+ * Authors: Enrico Sersale <enrico@imago.ro>
+ *          Riccardo Mottola <rm@gnu.org>
  * Date: August 2001
  *
  * This file is part of the GNUstep GWorkspace application
@@ -31,76 +32,28 @@
 
 #import "FSNodeRep.h"
 #import "FSNFunctions.h"
-#import "TShelfIconsView.h"
 #import "TShelfIcon.h"
+#import "TShelfFileIcon.h"
 #import "TShelfPBIcon.h"
+#import "TShelfIconsView.h"
 #import "GWorkspace.h"
+#import "TShelfWin.h"
 
 
 #define CELLS_WIDTH (80)
 #define EDIT_MARGIN (4)
 
-@interface TShelfIcon (TShelfIconsViewSorting)
-
-- (NSComparisonResult)iconCompare:(id)other;
-
-@end
-
-@implementation TShelfIcon (TShelfIconsViewSorting)
-
-- (NSComparisonResult)iconCompare:(id)other
-{
-  if ([other gridindex] == [self gridindex])
-    return NSOrderedSame;
-
-  if ([other gridindex] == NSNotFound)
-    return NSOrderedAscending;
-  if ([self gridindex] == NSNotFound)
-    return NSOrderedDescending;
-
-  if ([other gridindex] > [self gridindex])
-    return NSOrderedAscending;	
-  
-  return NSOrderedDescending;	
-}
-
-@end
-
-@interface TShelfPBIcon (TShelfIconsViewSorting)
-
-- (NSComparisonResult)pbiconCompare:(id)other;
-
-@end
-
-@implementation TShelfPBIcon (TShelfIconsViewSorting)
-
-- (NSComparisonResult)pbiconCompare:(id)other
-{
-  if ([other gridindex] == [self gridindex])
-    return NSOrderedSame;
-
-  if ([other gridindex] == NSNotFound)
-    return NSOrderedAscending;
-  if ([self gridindex] == NSNotFound)
-    return NSOrderedDescending;
-
-  if ([other gridindex] > [self gridindex])
-    return NSOrderedAscending;	
-  
-  return NSOrderedDescending;	
-}
-
-@end
 
 @implementation TShelfIconsView
 
 - (void) dealloc
 {
   [[NSNotificationCenter defaultCenter] removeObserver: self];
-	[self unsetWatchers];
-	if (gpoints != NULL) {
-		NSZoneFree (NSDefaultMallocZone(), gpoints);
-	}
+  [self unsetWatchers];
+  if (gpoints != NULL)
+    {
+      NSZoneFree (NSDefaultMallocZone(), gpoints);
+    }
   RELEASE (icons);  
   RELEASE (watchedPaths);
   RELEASE (dragImage);
@@ -252,12 +205,12 @@
       NSUInteger index;
 
       icon = [icons objectAtIndex: i];
-      index = [icon gridindex];
+      index = [icon gridIndex];
       [dict setObject: [NSNumber numberWithInt: index] forKey: @"index"];
 		
       if (iconsType == FILES_TAB)
 	{
-	  [dict setObject: [icon paths] forKey: @"paths"];
+	  [dict setObject: [(TShelfFileIcon *)icon paths] forKey: @"paths"];
 	}
       else
 	{
@@ -274,10 +227,12 @@
 - (void)addIconWithPaths:(NSArray *)iconpaths 
 	   withGridIndex:(NSUInteger)index 
 {
-  TShelfIcon *icon = [[TShelfIcon alloc] initForPaths: iconpaths 
-					    gridIndex: index inIconsView: self];
+  TShelfFileIcon *icon = [[TShelfFileIcon alloc] initForPaths: iconpaths
+                                                    gridIndex: index inIconsView: self];
   NSString *watched = [[iconpaths objectAtIndex: 0] stringByDeletingLastPathComponent];
-  
+
+  [icon setSingleClickLaunch:[(TShelfWin *)[gw tabbedShelf] singleClickLaunch]];
+
   if (gpoints != NULL)
     {
       if (index < pcount)
@@ -289,10 +244,10 @@
   [icons addObject: icon];  
   [self addSubview: icon];
   [self addSubview: [icon myLabel]];		
-  RELEASE (icon);    
-  [self sortIcons];	
-  [self resizeWithOldSuperviewSize: [self frame].size];  
-  
+  RELEASE (icon);
+  [self sortIcons];
+  [self resizeWithOldSuperviewSize: [self frame].size];
+
   if ([watchedPaths containsObject: watched] == NO)
     [self setWatcherForPath: watched];
 
@@ -307,20 +262,21 @@
 							  ofType: dtype
 						       gridIndex: index
 						     inIconsView: self];
-              
+
   if (gpoints != NULL)
     {
-      if (index < pcount) {
-	gpoints[index].used = 1;
-      }
+      if (index < pcount)
+	{
+	  gpoints[index].used = 1;
+	}
     }
 
-  [icons addObject: icon];  
+  [icons addObject: icon];
   [self addSubview: icon];
-  RELEASE (icon);    
-  [self sortIcons];	
-  [self resizeWithOldSuperviewSize: [self frame].size]; 
-  
+  RELEASE (icon);
+  [self sortIcons];
+  [self resizeWithOldSuperviewSize: [self frame].size];
+
   return icon; 
 }
 
@@ -329,33 +285,39 @@
   if (anIcon)
     {
       id label = [anIcon myLabel];
-      NSUInteger index = [anIcon gridindex];	
+      NSUInteger index = [anIcon gridIndex];
 
-    if (iconsType == FILES_TAB) {
-	    NSString *watched = [[[anIcon paths] objectAtIndex: 0] stringByDeletingLastPathComponent];
+      if (iconsType == FILES_TAB)
+	{
+	  NSString *watched = [[[anIcon paths] objectAtIndex: 0] stringByDeletingLastPathComponent];
 
-	    if ([watchedPaths containsObject: watched]) {
-		    [watchedPaths removeObject: watched];
-        
-        if ([watchedPaths containsObject: watched] == NO) {
-		      [self unsetWatcherForPath: watched];
-        }
+	  if ([watchedPaths containsObject: watched])
+	    {
+	      [watchedPaths removeObject: watched];
+
+	      if ([watchedPaths containsObject: watched] == NO)
+		{
+		  [self unsetWatcherForPath: watched];
+		}
 	    }
-      
-      if (label && [[self subviews] containsObject: label]) {
-        [label removeFromSuperview];
+
+	  if (label && [[self subviews] containsObject: label])
+	    {
+	      [label removeFromSuperview];
+	    }
+	}
+
+    if (focusedIcon == anIcon)
+      {
+	focusedIcon = nil;
+	[self updateFocusedIconLabel];
       }
-    }
-    
-    if (focusedIcon == anIcon) {
-      focusedIcon = nil;
-      [self updateFocusedIconLabel];
-    }
-    
-    if ([[self subviews] containsObject: anIcon]) {
-      [anIcon removeFromSuperview];
-    }
-    
+
+    if ([[self subviews] containsObject: anIcon])
+      {
+	[anIcon removeFromSuperview];
+      }
+
     [icons removeObject: anIcon];
     gpoints[index].used = 0;
     [self resizeWithOldSuperviewSize: [self frame].size];  
@@ -366,10 +328,10 @@
 {
   NSUInteger count = [icons count];
   NSUInteger i;
-  
+
   for (i = 0; i < count; i++)
     {
-      TShelfPBIcon *icon = [icons objectAtIndex: count-i];
+      TShelfPBIcon *icon = [icons objectAtIndex: count-i-1];
       
       if ([[icon dataType] isEqual: type])
 	{
@@ -394,31 +356,36 @@
   NSRect labelRect;
   
   icon = (TShelfIcon *)anIcon;	
-	label = [icon myLabel];
+  label = [icon myLabel];
   
-	iconwidth = [icon frame].size.width;
-	labwidth = [label frame].size.width;
+  iconwidth = [icon frame].size.width;
+  labwidth = [label frame].size.width;
 
-	if (iconwidth > labwidth) {
-		labxpos = [icon frame].origin.x + ((iconwidth - labwidth) / 2);
-	} else {
-		labxpos = [icon frame].origin.x - ((labwidth - iconwidth) / 2);
-	}
-	
-	labelRect = NSMakeRect(labxpos, [icon frame].origin.y - 14, labwidth, 14);
-	[label setFrame: labelRect];
+  if (iconwidth > labwidth)
+    {
+      labxpos = [icon frame].origin.x + ((iconwidth - labwidth) / 2);
+    }
+  else
+    {
+      labxpos = [icon frame].origin.x - ((labwidth - iconwidth) / 2);
+    }
+
+  labelRect = NSMakeRect(labxpos, [icon frame].origin.y - 14, labwidth, 14);
+  [label setFrame: labelRect];
 }
 
 - (BOOL)hasSelectedIcon
 {
   NSUInteger i;
   
-  for (i = 0; i < [icons count]; i++) {
-    TShelfIcon *icon = [icons objectAtIndex: i];
-    if ([icon isSelect]) {  
-      return YES;
+  for (i = 0; i < [icons count]; i++)
+    {
+      TShelfIcon *icon = [icons objectAtIndex: i];
+      if ([icon isSelected])
+	{
+	  return YES;
+	}
     }
-  }  
 
   return NO;
 }
@@ -490,7 +457,7 @@
 
 - (void)sortIcons
 {
-  SEL sel = (iconsType == FILES_TAB) ? @selector(iconCompare:) : @selector(pbiconCompare:);
+  SEL sel = @selector(iconCompare:);
   [icons sortUsingSelector: sel];
 }
 
@@ -508,13 +475,15 @@
 {
   NSUInteger i;
 
-  for (i = 0; i < [icons count]; i++) {
-    id icon = [icons objectAtIndex: i];
-    
-    if ([icon respondsToSelector: @selector(renewIcon)]) {
-      [icon renewIcon];
+  for (i = 0; i < [icons count]; i++)
+    {
+      id icon = [icons objectAtIndex: i];
+
+      if ([icon respondsToSelector: @selector(renewIcon)])
+	{
+	  [icon renewIcon];
+	}
     }
-  }  
 }
 
 - (id)selectedIcon
@@ -523,7 +492,7 @@
   
   for (i = 0; i < [icons count]; i++) {
     id icon = [icons objectAtIndex: i];
-    if ([icon isSelect]) {  
+    if ([icon isSelected]) {  
       return icon;
     }
   }  
@@ -550,7 +519,7 @@
 
       for (i = 0; i < count; i++)
 	{
-	  TShelfIcon *icon = [icons objectAtIndex: i];
+	  TShelfFileIcon *icon = [icons objectAtIndex: i];
 	  NSArray *iconpaths = [icon paths];
 	  NSUInteger j;
 
@@ -580,7 +549,7 @@
       for (i = 0; i < count; i++)
 	{
 	  BOOL deleted = NO;
-	  TShelfIcon *icon = [icons objectAtIndex: i];
+	  TShelfFileIcon *icon = [icons objectAtIndex: i];
 	  NSArray *iconpaths = [icon paths];
 	  NSUInteger j;
 	  
@@ -588,13 +557,13 @@
 	    {
 	      NSString *op = [iconpaths objectAtIndex: j];
 	      NSUInteger m;
-	      
+
 	      for (m = 0; m < [hpaths count]; m++)
 		{
 		  NSString *fp = [hpaths objectAtIndex: m]; 
 		  
 		  if (isSubpathOfPath(fp, op) || [fp isEqual: op])
-		    {  
+		    {
 		      [self removeIcon: icon];
 		      count--;
 		      i--;
@@ -626,40 +595,49 @@
   NSArray *files = [dict objectForKey: @"files"];	 
 
   if ([operation isEqual: NSWorkspaceMoveOperation] 
-        || [operation isEqual: NSWorkspaceDestroyOperation]
-				|| [operation isEqual: @"GWorkspaceRenameOperation"]
-				|| [operation isEqual: NSWorkspaceRecycleOperation]
-				|| [operation isEqual: @"GWorkspaceRecycleOutOperation"]
-				|| [operation isEqual: @"GWorkspaceEmptyRecyclerOperation"]) {
-    NSMutableArray *paths = [NSMutableArray array];
-    NSArray *iconpaths;
-    NSUInteger i, j, m;
+      || [operation isEqual: NSWorkspaceDestroyOperation]
+      || [operation isEqual: @"GWorkspaceRenameOperation"]
+      || [operation isEqual: NSWorkspaceRecycleOperation]
+      || [operation isEqual: @"GWorkspaceRecycleOutOperation"]
+      || [operation isEqual: @"GWorkspaceEmptyRecyclerOperation"])
+    {
+      NSMutableArray *paths = [NSMutableArray array];
+      NSArray *iconpaths;
+      NSUInteger i, j, m;
 
-    for (i = 0; i < [files count]; i++) {
-      NSString *s = [source stringByAppendingPathComponent: [files objectAtIndex: i]];
-      [paths addObject: s];
+      for (i = 0; i < [files count]; i++)
+	{
+	  NSString *s = [source stringByAppendingPathComponent: [files objectAtIndex: i]];
+	  [paths addObject: s];
+	}
+
+      for (i = 0; i < [icons count]; i++)
+	{
+	  TShelfIcon *icon = [icons objectAtIndex: i];
+
+	  if ([icon isKindOfClass:[TShelfFileIcon class]])
+	    {
+	      iconpaths = [(TShelfFileIcon *)icon paths];
+
+	      for (j = 0; j < [iconpaths count]; j++)
+		{
+		  NSString *op = [iconpaths objectAtIndex: j];
+
+		  for (m = 0; m < [paths count]; m++)
+		    {
+		      NSString *fp = [paths objectAtIndex: m];
+
+		      if ([op hasPrefix: fp])
+			{
+			  [icon setLocked: YES];
+			  break;
+			}
+		    }
+		}
+	    } // if TShelfFileIcon
+	}
     }
 
-	  for (i = 0; i < [icons count]; i++) {
-		  TShelfIcon *icon = [icons objectAtIndex: i];
-      
-      iconpaths = [icon paths];
-
-	    for (j = 0; j < [iconpaths count]; j++) {
-        NSString *op = [iconpaths objectAtIndex: j];
-
-	      for (m = 0; m < [paths count]; m++) {
-          NSString *fp = [paths objectAtIndex: m]; 
-
-          if ([op hasPrefix: fp]) {
-            [icon setLocked: YES]; 
-            break;
-          }
-        }
-      }
-	  }
-  }
-
   RELEASE (arp);
 }
 
@@ -671,59 +649,67 @@
   NSString *source = [dict objectForKey: @"source"];
   NSArray *files = [dict objectForKey: @"files"];
   
-  if ([operation isEqual: @"GWorkspaceRenameOperation"]) {
-		files = [NSArray arrayWithObject: [source lastPathComponent]];
-    source = [source stringByDeletingLastPathComponent];
-  }	
+  if ([operation isEqual: @"GWorkspaceRenameOperation"])
+    {
+      files = [NSArray arrayWithObject: [source lastPathComponent]];
+      source = [source stringByDeletingLastPathComponent];
+    }
 		                    
   if ([operation isEqual: NSWorkspaceMoveOperation] 
-        || [operation isEqual: NSWorkspaceDestroyOperation]
-				|| [operation isEqual: @"GWorkspaceRenameOperation"]
-				|| [operation isEqual: NSWorkspaceRecycleOperation]
-				|| [operation isEqual: @"GWorkspaceRecycleOutOperation"]
-				|| [operation isEqual: @"GWorkspaceEmptyRecyclerOperation"]) {
-    NSMutableArray *paths = [NSMutableArray arrayWithCapacity: 1];
-    TShelfIcon *icon;
-    NSArray *iconpaths;
-    NSUInteger count;
-    NSUInteger i, j, m;
+      || [operation isEqual: NSWorkspaceDestroyOperation]
+      || [operation isEqual: @"GWorkspaceRenameOperation"]
+      || [operation isEqual: NSWorkspaceRecycleOperation]
+      || [operation isEqual: @"GWorkspaceRecycleOutOperation"]
+      || [operation isEqual: @"GWorkspaceEmptyRecyclerOperation"])
+    {
+      NSMutableArray *paths = [NSMutableArray arrayWithCapacity: 1];
+      TShelfIcon *icon;
+      NSArray *iconpaths;
+      NSUInteger count;
+      NSUInteger i, j, m;
 
-    for (i = 0; i < [files count]; i++) {
-      NSString *s = [source stringByAppendingPathComponent: [files objectAtIndex: i]];
-      [paths addObject: s];
-    }
+      for (i = 0; i < [files count]; i++)
+	{
+	  NSString *s = [source stringByAppendingPathComponent: [files objectAtIndex: i]];
+	  [paths addObject: s];
+	}
         
-    count = [icons count];  
-	  for (i = 0; i < count; i++) {
-      BOOL deleted = NO;
-		  icon = [icons objectAtIndex: i];
-      iconpaths = [icon paths];
+      count = [icons count];  
+      for (i = 0; i < count; i++)
+	{
+	  BOOL deleted = NO;
+	  icon = [icons objectAtIndex: i];
+	  if ([icon isKindOfClass:[TShelfFileIcon class]])
+	    {
+	      iconpaths = [(TShelfFileIcon *)icon paths];
 
-	    for (j = 0; j < [iconpaths count]; j++) {
-        NSString *op = [iconpaths objectAtIndex: j];
+	      for (j = 0; j < [iconpaths count]; j++)
+		{
+		  NSString *op = [iconpaths objectAtIndex: j];
 
-	      for (m = 0; m < [paths count]; m++) {
-          NSString *fp = [paths objectAtIndex: m]; 
+		  for (m = 0; m < [paths count]; m++)
+		    {
+		      NSString *fp = [paths objectAtIndex: m]; 
 
-          if ([op hasPrefix: fp]) {
-            [self removeIcon: icon];
-            count--;
-            i--;
-            deleted = YES;
-            break;
-          }
+		      if ([op hasPrefix: fp])
+			{
+			  [self removeIcon: icon];
+			  count--;
+			  i--;
+			  deleted = YES;
+			  break;
+			}
 
-          if (deleted) {
-            break;
-          } 
-        }
+		      if (deleted)
+			break;
+		    }
 
-        if (deleted) {
-          break;
-        }       
-      }
-	  }
-  }
+		  if (deleted)
+		    break;
+		}
+	    } // if TShelfFileIcon
+	}
+    }
   
   RELEASE (arp);
 }
@@ -731,147 +717,174 @@
 - (void)watcherNotification:(NSNotification *)notification
 {
   CREATE_AUTORELEASE_POOL(arp);
-	NSDictionary *notifdict = (NSDictionary *)[notification object];
+  NSDictionary *notifdict = (NSDictionary *)[notification object];
   NSString *path = [notifdict objectForKey: @"path"];
-	NSString *event = [notifdict objectForKey: @"event"];
-	NSEnumerator *enumerator;
+  NSString *event = [notifdict objectForKey: @"event"];
+  NSEnumerator *enumerator;
   NSString *wpath;
   BOOL contained = NO;
   NSUInteger i;
-  
-  if (iconsType == DATA_TAB) {
-    NSUInteger count = [icons count];
-    
-    if ([event isEqual: @"GWFileDeletedInWatchedDirectory"]) { 
-      NSArray *files = [notifdict objectForKey: @"files"];
-    
-      for (i = 0; i < count; i++) {
-        TShelfPBIcon *icon = [icons objectAtIndex: i];
-        NSString *dataPath = [icon dataPath];
-        NSUInteger j;
-				  
-        for (j = 0; j < [files count]; j++) {
-          NSString *fname = [files objectAtIndex: j];
-          NSString *fullPath = [path stringByAppendingPathComponent: fname];
 
-          if ([fullPath isEqual: dataPath]) {
-            [self removeIcon: icon];
-            count--;
-            i--;
-          }
-        }
+  if (iconsType == DATA_TAB)
+    {
+      NSUInteger count = [icons count];
+
+      if ([event isEqual: @"GWFileDeletedInWatchedDirectory"])
+	{
+	  NSArray *files = [notifdict objectForKey: @"files"];
+
+	  for (i = 0; i < count; i++)
+	    {
+	      TShelfPBIcon *icon = [icons objectAtIndex: i];
+	      NSString *dataPath = [icon dataPath];
+	      NSUInteger j;
+				  
+	      for (j = 0; j < [files count]; j++)
+		{
+		  NSString *fname = [files objectAtIndex: j];
+		  NSString *fullPath = [path stringByAppendingPathComponent: fname];
+
+		  if ([fullPath isEqual: dataPath])
+		    {
+		      [self removeIcon: icon];
+		      count--;
+		      i--;
+		    }
+		}
+	    }
+	}
+    }
+  else
+    {
+      if ([event isEqual: @"GWFileCreatedInWatchedDirectory"])
+	{
+	  RELEASE (arp);
+	  return;
+	}
+
+      enumerator = [watchedPaths objectEnumerator];
+
+      while ((wpath = [enumerator nextObject]))
+	{
+	  if (([wpath isEqual: path]) || (isSubpathOfPath(path, wpath)))
+	    {
+	      contained = YES;
+	      break;
+	    }
+	}
+
+    if (contained)
+      {
+	id icon;
+	NSArray *ipaths;
+	NSString *ipath;
+	NSUInteger count = [icons count];
+
+	if ([event isEqual: @"GWWatchedPathDeleted"])
+	  {
+	    for (i = 0; i < count; i++)
+	      {
+		icon = [icons objectAtIndex: i];
+		ipaths = [icon paths];
+		ipath = [ipaths objectAtIndex: 0];
+
+		if (isSubpathOfPath(path, ipath))
+		  {
+		    [self removeIcon: icon];
+		    count--;
+		    i--;
+		  }
+	      }
+
+	    RELEASE (arp);
+	    return;
+	  }
+
+	if ([event isEqual: @"GWFileDeletedInWatchedDirectory"])
+	  {
+	    NSArray *files = [notifdict objectForKey: @"files"];
+
+	    for (i = 0; i < count; i++)
+	      {
+		NSUInteger j;
+
+		icon = [icons objectAtIndex: i];
+		ipaths = [icon paths];
+
+		if ([ipaths count] == 1)
+		  {
+		    ipath = [ipaths objectAtIndex: 0];
+
+		    for (j = 0; j < [files count]; j++)
+		      {
+			NSString *fname = [files objectAtIndex: j];
+			NSString *fullPath = [path stringByAppendingPathComponent: fname];
+
+			if ((isSubpathOfPath(fullPath, ipath))
+			    || ([ipath isEqual: fullPath]))
+			  {
+			    [self removeIcon: icon];
+			    count--;
+			    i--;
+			    break;
+			  }
+		      }
+
+		  }
+		else
+		  {
+		    for (j = 0; j < [files count]; j++)
+		      {
+			NSString *fname = [files objectAtIndex: j];
+			NSString *fullPath = [path stringByAppendingPathComponent: fname];
+			BOOL deleted = NO;
+			NSUInteger m;
+
+			if (deleted)
+			  {
+			    break;
+			  }
+
+			ipath = [ipaths objectAtIndex: 0];
+			if (isSubpathOfPath(fullPath, ipath))
+			  {
+			    [self removeIcon: icon];
+			    count--;
+			    i--;
+			    break;
+			  }
+
+			for (m = 0; m < [ipaths count]; m++)
+			  {
+			    ipath = [ipaths objectAtIndex: m];
+
+			    if ([ipath isEqual: fullPath])
+			      {
+				NSMutableArray *newpaths;
+
+				if ([ipaths count] == 1)
+				  {
+				    [self removeIcon: icon];
+				    count--;
+				    i--;
+				    deleted = YES;
+				    break;
+				  }
+
+				newpaths = [ipaths mutableCopy];
+				[newpaths removeObject: ipath];
+				[icon setPaths: newpaths];
+				ipaths = [icon paths];
+				RELEASE (newpaths);
+			      }
+			  }
+
+		      }
+		  }
+	      }
+	  }
       }
     }
-  } else {
-	  if ([event isEqual: @"GWFileCreatedInWatchedDirectory"]) {
-      RELEASE (arp);
-		  return;
-	  }
-    
-    enumerator = [watchedPaths objectEnumerator]; 
-    
-    while ((wpath = [enumerator nextObject])) {
-		  if (([wpath isEqual: path]) || (isSubpathOfPath(path, wpath))) {
-			  contained = YES;
-			  break;
-		  }
-    }
-
-    if (contained) {
-		  id icon;
-		  NSArray *ipaths;
-		  NSString *ipath;
-		  NSUInteger count = [icons count];
-
-		  if ([event isEqual: @"GWWatchedPathDeleted"]) {		
-			  for (i = 0; i < count; i++) {
-				  icon = [icons objectAtIndex: i];
-				  ipaths = [icon paths];
-				  ipath = [ipaths objectAtIndex: 0];
-
-				  if (isSubpathOfPath(path, ipath)) {
-					  [self removeIcon: icon];
-					  count--;
-					  i--;
-				  }
-			  }
-        
-        RELEASE (arp);
-			  return;
-		  }		
-
-		  if ([event isEqual: @"GWFileDeletedInWatchedDirectory"]) { 
-			  NSArray *files = [notifdict objectForKey: @"files"];
-
-			  for (i = 0; i < count; i++) {
-				  NSUInteger j;
-
-				  icon = [icons objectAtIndex: i];
-				  ipaths = [icon paths];				
-
-				  if ([ipaths count] == 1) {
-					  ipath = [ipaths objectAtIndex: 0];
-
-					  for (j = 0; j < [files count]; j++) {
-						  NSString *fname = [files objectAtIndex: j];
-						  NSString *fullPath = [path stringByAppendingPathComponent: fname];
-
-						  if ((isSubpathOfPath(fullPath, ipath))
-															  || ([ipath isEqual: fullPath])) {
-							  [self removeIcon: icon];
-							  count--;
-							  i--;
-							  break;
-						  }
-					  }
-
-				  } else {
-					  for (j = 0; j < [files count]; j++) {
-						  NSString *fname = [files objectAtIndex: j];
-						  NSString *fullPath = [path stringByAppendingPathComponent: fname];
-						  BOOL deleted = NO;
-						  NSUInteger m;
-
-						  if (deleted) {
-							  break;
-						  }
-
-						  ipath = [ipaths objectAtIndex: 0];
-						  if (isSubpathOfPath(fullPath, ipath)) {
-							  [self removeIcon: icon];
-							  count--;
-							  i--;
-							  break;
-						  }
-
-						  for (m = 0; m < [ipaths count]; m++) {
-							  ipath = [ipaths objectAtIndex: m];
-
-							  if ([ipath isEqual: fullPath]) {
-								  NSMutableArray *newpaths;
-
-								  if ([ipaths count] == 1) {
-									  [self removeIcon: icon];
-									  count--;
-									  i--;			
-									  deleted = YES;
-									  break;	
-								  }
-
-								  newpaths = [ipaths mutableCopy];
-								  [newpaths removeObject: ipath];
-								  [icon setPaths: newpaths];
-								  ipaths = [icon paths];
-								  RELEASE (newpaths);
-							  }
-						  }
-
-					  }
-				  }
-			  }
-		  }
-	  }
-  }
 
   RELEASE (arp);
 }
@@ -881,14 +894,15 @@
   NSEnumerator *enumerator = [watchedPaths objectEnumerator]; 
   NSString *wpath;
 
-	while ((wpath = [enumerator nextObject])) {
-    [self setWatcherForPath: wpath]; 
-  }
+  while ((wpath = [enumerator nextObject]))
+    {
+      [self setWatcherForPath: wpath];
+    }
 }
 
 - (void)setWatcherForPath:(NSString *)path
 {
-	[gw addWatcherForPath: path];
+  [gw addWatcherForPath: path];
 }
 
 - (void)unsetWatchers
@@ -896,14 +910,15 @@
   NSEnumerator *enumerator = [watchedPaths objectEnumerator]; 
   NSString *wpath;
 
-	while ((wpath = [enumerator nextObject])) {
-    [self unsetWatcherForPath: wpath]; 
-  }
+  while ((wpath = [enumerator nextObject]))
+    {
+      [self unsetWatcherForPath: wpath];
+    }
 }
 
 - (void)unsetWatcherForPath:(NSString *)path
 {
-	[gw removeWatcherForPath: path];
+  [gw removeWatcherForPath: path];
 }
 
 - (void)makePositions
@@ -913,59 +928,68 @@
   
   wdt = [self bounds].size.width;
   hgt = [self bounds].size.height;
-	
+
   pcount = (NSUInteger)((wdt - 16) / cellsWidth);
-		
-  if (gpoints != NULL) {
-		NSZoneFree (NSDefaultMallocZone(), gpoints);
-	} 
-	gpoints = NSZoneMalloc (NSDefaultMallocZone(), sizeof(gridpoint) * pcount);		
-	
+
+  if (gpoints != NULL)
+    {
+      NSZoneFree (NSDefaultMallocZone(), gpoints);
+    }
+  gpoints = NSZoneMalloc (NSDefaultMallocZone(), sizeof(gridpoint) * pcount);
+
   x = 16;
   y = hgt - 59;
-	
-	for (i = 0; i < pcount; i++) {
-		if (i > 0) {
-			x += cellsWidth;      
-    }
-    gpoints[i].x = x;
-    gpoints[i].y = y;
-    gpoints[i].index = i;
-    
-    if (x < (wdt - cellsWidth)) {
-      gpoints[i].used = 0;
-    } else {
-		  gpoints[i].used = 1;
-    }
+
+  for (i = 0; i < pcount; i++)
+    {
+      if (i > 0)
+	{
+	  x += cellsWidth;
 	}
+      gpoints[i].x = x;
+      gpoints[i].y = y;
+      gpoints[i].index = i;
+
+      if (x < (wdt - cellsWidth))
+	{
+	  gpoints[i].used = 0;
+	}
+      else
+	{
+	  gpoints[i].used = 1;
+	}
+    }
 }
 
 - (gridpoint *)gridPointNearestToPoint:(NSPoint)p
 {
   NSRect r = [self bounds];
-	CGFloat maxx = r.size.width;
-	CGFloat maxy = r.size.height;
-	float px = p.x;
-	float py = p.y;	
-	float minx = maxx;
-	float miny = maxy;
-	int pos = -1;
-	NSUInteger i;
+  CGFloat maxx = r.size.width;
+  CGFloat maxy = r.size.height;
+  float px = p.x;
+  float py = p.y;
+  float minx = maxx;
+  float miny = maxy;
+  int pos = -1;
+  NSUInteger i;
 		
-	for (i = 0; i < pcount; i++) {
-		if (gpoints[i].y > 0) {
-			float dx = max(px, gpoints[i].x) - min(px, gpoints[i].x);
-			float dy = max(py, gpoints[i].y) - min(py, gpoints[i].y);
+  for (i = 0; i < pcount; i++)
+    {
+      if (gpoints[i].y > 0)
+	{
+	  float dx = max(px, gpoints[i].x) - min(px, gpoints[i].x);
+	  float dy = max(py, gpoints[i].y) - min(py, gpoints[i].y);
 
-			if ((dx <= minx) && (dy <= miny)) {
-				minx = dx;
-				miny = dy;
-				pos = i;
-			}
-		}
+	  if ((dx <= minx) && (dy <= miny))
+	    {
+	      minx = dx;
+	      miny = dy;
+	      pos = i;
+	    }
 	}
-	
-	return &gpoints[pos];
+    }
+
+  return &gpoints[pos];
 }
 
 - (BOOL)isFreePosition:(NSPoint)pos
@@ -975,9 +999,10 @@
   for (i = 0; i < [icons count]; i++)
     {
       NSPoint p = [[icons objectAtIndex: i] position];
-      if (NSEqualPoints(pos, p)) {
-        return NO;
-      }
+      if (NSEqualPoints(pos, p))
+	{
+	  return NO;
+	}
     }
   
   return YES;
@@ -990,8 +1015,8 @@
 
 - (void)setFrame:(NSRect)frameRect
 {
-	[super setFrame: frameRect];	
-	makePos(self, makePosSel);
+  [super setFrame: frameRect];
+  makePos(self, makePosSel);
 }
 
 - (void)resizeWithOldSuperviewSize:(NSSize)oldFrameSize
@@ -1010,9 +1035,9 @@
     }
 	
   for (i = 0; i < [icons count]; i++)
-    {	
+    {
       id icon	 = [icons objectAtIndex: i];
-      NSUInteger index = [icon gridindex];		
+      NSUInteger index = [icon gridIndex];
       gridpoint gpoint = gpoints[index];
       NSPoint p = NSMakePoint(gpoint.x, gpoint.y);
       NSRect r = NSMakeRect(p.x, p.y, 64, 52);
@@ -1023,7 +1048,7 @@
       
       if (iconsType == FILES_TAB)
         {
-          [self setLabelRectOfIcon: icon];		
+          [self setLabelRectOfIcon: icon];
         }
     }
 	
@@ -1035,23 +1060,26 @@
 {
   [self unselectOtherIcons: nil];
   
-  if (iconsType == DATA_TAB) {
-    [self setCurrentPBIcon: nil];
-  }
+  if (iconsType == DATA_TAB)
+    {
+      [self setCurrentPBIcon: nil];
+    }
 }
 
 - (void)drawRect:(NSRect)rect
 {  
   [super drawRect: rect];
 
-	if (dragImage != nil) {
-    gridpoint *gpoint = [self gridPointNearestToPoint: dragPoint];
+  if (dragImage != nil)
+    {
+      gridpoint *gpoint = [self gridPointNearestToPoint: dragPoint];
   
-    if (gpoint->used == 0) {
-      NSPoint p = NSMakePoint(dragPoint.x + 8, dragPoint.y);
-		  [dragImage dissolveToPoint: p fraction: 0.3];
-    }
+      if (gpoint->used == 0)
+	{
+	  NSPoint p = NSMakePoint(dragPoint.x + 8, dragPoint.y);
+	  [dragImage dissolveToPoint: p fraction: 0.3];
 	}
+    }
 }
 
 - (BOOL)acceptsFirstResponder
@@ -1064,94 +1092,118 @@
 	return YES;
 }
 
+- (void)setSingleClickLaunch:(BOOL)value
+{
+  NSUInteger i;
+
+  for (i = 0; i < [icons count]; i++)
+    {
+      TShelfIcon *icon;
+
+      icon = [icons objectAtIndex: i];
+      [icon setSingleClickLaunch: value];
+    }
+}
+
 @end
 
 @implementation TShelfIconsView(PBoardOperations)
 
 - (void)setCurrentPBIcon:(id)anIcon
 {
-  if (anIcon) {
-    NSString *dataPath = [anIcon dataPath];
-    NSString *dataType = [anIcon dataType];
-    NSImage *icn = [anIcon icon];
-    NSData *data = [NSData dataWithContentsOfFile: dataPath];
+  if (anIcon)
+    {
+      NSString *dataPath = [anIcon dataPath];
+      NSString *dataType = [anIcon dataType];
+      NSImage *icn = [anIcon icon];
+      NSData *data = [NSData dataWithContentsOfFile: dataPath];
     
-    if (data) {
-      [gw showPasteboardData: data ofType: dataType typeIcon: icn];
+      if (data)
+	{
+	  [gw showPasteboardData: data ofType: dataType typeIcon: icn];
+	}
+    }
+  else
+    {
+      [gw resetSelectedPaths];
     }
-  } else {
-    [gw resetSelectedPaths];
-  }
 }
 
 - (void)doCut
 {
   TShelfPBIcon *icon = [self selectedIcon];
 
-  if (icon) {
-    NSString *dataPath = [icon dataPath];
+  if (icon)
+    {
+      NSString *dataPath = [icon dataPath];
   
-    RETAIN (dataPath);
-    [self doCopy];
-    [self removeIcon: icon];
-    [fm removeFileAtPath: dataPath handler: nil];
-    RELEASE (dataPath);
-    [gw resetSelectedPaths];
-  }
+      RETAIN (dataPath);
+      [self doCopy];
+      [self removeIcon: icon];
+      [fm removeFileAtPath: dataPath handler: nil];
+      RELEASE (dataPath);
+      [gw resetSelectedPaths];
+    }
 }
 
 - (void)doCopy
 {
   TShelfPBIcon *icon = [self selectedIcon];
 
-  if (icon) {
-    NSString *dataPath = [icon dataPath];
-    NSString *dataType = [icon dataType];
-    NSData *data = [NSData dataWithContentsOfFile: dataPath];
+  if (icon)
+    {
+      NSString *dataPath = [icon dataPath];
+      NSString *dataType = [icon dataType];
+      NSData *data = [NSData dataWithContentsOfFile: dataPath];
 
-    if (data) {
-      NSPasteboard *pb = [NSPasteboard generalPasteboard];
+      if (data)
+	{
+	  NSPasteboard *pb = [NSPasteboard generalPasteboard];
       
-      [pb declareTypes: [NSArray arrayWithObject: dataType] owner: self];
-      [pb setData: data forType: dataType];
+	  [pb declareTypes: [NSArray arrayWithObject: dataType] owner: self];
+	  [pb setData: data forType: dataType];
+	}
     }
-  }
 }
 
 - (void)doPaste
 {
   NSData *data;
   NSString *type;
-  
+
   data = [self readSelectionFromPasteboard: [NSPasteboard generalPasteboard]
                                     ofType: &type];
-     
+
   if (data && [[TShelfPBIcon dataTypes] containsObject: type]) {         
     NSString *dpath = [gw tshelfPBFilePath];
     NSUInteger index = NSNotFound; 
     NSUInteger i;
-    
-    for (i = 0; i < pcount; i++) {
-      if (gpoints[i].used == 0) {
-        index = i;
-        break;
+
+    for (i = 0; i < pcount; i++)
+      {
+	if (gpoints[i].used == 0)
+	  {
+	    index = i;
+	    break;
+	  }
       }
-    }
-    
-    if (index == NSNotFound) {
-      NSRunAlertPanel(NSLocalizedString(@"Error!", @""),
+
+    if (index == NSNotFound)
+      {
+	NSRunAlertPanel(NSLocalizedString(@"Error!", @""),
                         NSLocalizedString(@"No space left on this tab", @""),
                         NSLocalizedString(@"Ok", @""),
                         nil,
                         nil);
-      return;
-    }
-  
-    if ([data writeToFile: dpath atomically: YES]) {
-      [self addPBIconForDataAtPath: dpath
-                          dataType: type
-					           withGridIndex: index];
-    }
+	return;
+      }
+
+    if ([data writeToFile: dpath atomically: YES])
+      {
+	[self addPBIconForDataAtPath: dpath
+			    dataType: type
+		       withGridIndex: index];
+      }
   }
 }
 
@@ -1163,18 +1215,21 @@
   NSString *type;
   NSUInteger i;
   
-  if ((types == nil) || ([types count] == 0)) {
-    return nil;
-  }
+  if ((types == nil) || ([types count] == 0))
+    {
+      return nil;
+    }
 
-  for (i = 0; i < [types count]; i++) {
-    type = [types objectAtIndex: 0];
-    data = [pboard dataForType: type];
-    if (data) {
-      *pbtype = type;
-      return data;
+  for (i = 0; i < [types count]; i++)
+    {
+      type = [types objectAtIndex: 0];
+      data = [pboard dataForType: type];
+      if (data)
+	{
+	  *pbtype = type;
+	  return data;
+	}
     }
-  }
   
   return nil;
 }
@@ -1191,7 +1246,7 @@
   gridpoint *gpoint;
   
   DESTROY (dragImage);
-  
+
   if (iconsType == FILES_TAB)
     {
       if ((sourceDragMask == NSDragOperationCopy) || (sourceDragMask == NSDragOperationLink))
@@ -1200,131 +1255,144 @@
         }
     }
   
-  if (iconsType == FILES_TAB) {  
-    if ([[pb types] indexOfObject: NSFilenamesPboardType] != NSNotFound) {
-      NSArray *sourcePaths = [pb propertyListForType: NSFilenamesPboardType]; 
-      
-      if ([sourcePaths count]) {
-        NSString *basePath = [sourcePaths objectAtIndex: 0];
-      
-        basePath = [basePath stringByDeletingLastPathComponent];
-        
-        if ([basePath isEqual: [gw trashPath]]) {
-          found = NO;
-        }
-      
-      } else {
-        found = NO;
-      }
-    } else {
-      found = NO;
+  if (iconsType == FILES_TAB)
+    {
+      if ([[pb types] indexOfObject: NSFilenamesPboardType] != NSNotFound)
+	{
+	  NSArray *sourcePaths = [pb propertyListForType: NSFilenamesPboardType];
+
+	  if ([sourcePaths count])
+	    {
+	      NSString *basePath = [sourcePaths objectAtIndex: 0];
+
+	      basePath = [basePath stringByDeletingLastPathComponent];
+	      if ([basePath isEqual: [gw trashPath]])
+		{
+		  found = NO;
+		}
+	    }
+	  else
+	    {
+	      found = NO;
+	    }
+	}
+      else
+	{
+	  found = NO;
+	}
     }
-  } else {
-    NSArray *types = [pb types];
+  else
+    {
+      NSArray *types = [pb types];
     
-    if (([types indexOfObject: NSStringPboardType] == NSNotFound)
+      if (([types indexOfObject: NSStringPboardType] == NSNotFound)
           && ([types indexOfObject: NSRTFPboardType] == NSNotFound)
           && ([types indexOfObject: NSRTFDPboardType] == NSNotFound)
           && ([types indexOfObject: NSTIFFPboardType] == NSNotFound)
           && ([types indexOfObject: NSFileContentsPboardType] == NSNotFound)
           && ([types indexOfObject: NSColorPboardType] == NSNotFound)
-          && ([types indexOfObject: @"IBViewPboardType"] == NSNotFound)) {
-      found = NO;
+          && ([types indexOfObject: @"IBViewPboardType"] == NSNotFound))
+	{
+	  found = NO;
+	}
     }
-  }   
     
-  if (found) {
-    isDragTarget = YES;	
-		DESTROY (dragImage);
-		dragPoint = [sender draggedImageLocation];	
-		dragPoint = [self convertPoint: dragPoint 
-                                      fromView: [[self window] contentView]];	
-		gpoint = [self gridPointNearestToPoint: dragPoint];						
-		dragPoint = NSMakePoint(gpoint->x, gpoint->y);
-    ASSIGN (dragImage, [sender draggedImage]);
-		dragRect = NSMakeRect(dragPoint.x + 8, dragPoint.y, [dragImage size].width, [dragImage size].height);
-		[self setNeedsDisplay: YES];
-    
-    if (iconsType == FILES_TAB) { 
+  if (found)
+    {
+      isDragTarget = YES;
+      DESTROY (dragImage);
+      dragPoint = [sender draggedImageLocation];
+      dragPoint = [self convertPoint: dragPoint 
+			    fromView: [[self window] contentView]];
+      gpoint = [self gridPointNearestToPoint: dragPoint];
+      dragPoint = NSMakePoint(gpoint->x, gpoint->y);
+      ASSIGN (dragImage, [sender draggedImage]);
+      dragRect = NSMakeRect(dragPoint.x + 8, dragPoint.y, [dragImage size].width, [dragImage size].height);
+      [self setNeedsDisplay: YES];
+
       return NSDragOperationEvery;
-    } else {
-      return NSDragOperationCopy;
     }
-  }
-    
-  isDragTarget = NO;	  
+
+  isDragTarget = NO;
   return NSDragOperationNone;
 }
 
 - (NSDragOperation)draggingUpdated:(id <NSDraggingInfo>)sender
 {
   NSDragOperation sourceDragMask = [sender draggingSourceOperationMask];
-	NSPoint p = [sender draggedImageLocation];
-	p = [self convertPoint: p fromView: [[self window] contentView]];
+  NSPoint p = [sender draggedImageLocation];
+  p = [self convertPoint: p fromView: [[self window] contentView]];
 
-	if (isDragTarget == NO) {
-		return NSDragOperationNone;
-	}
-
-  if (iconsType == FILES_TAB) {
-	  if ((sourceDragMask == NSDragOperationCopy) 
-												  || (sourceDragMask == NSDragOperationLink)) {
-      if (dragImage) {
-        DESTROY (dragImage);
-        [self setNeedsDisplayInRect: dragRect]; 
-      }                   
-		  return NSDragOperationNone;
-	  }	
-  }
-
-	if (NSEqualPoints(dragPoint, p) == NO) {
-		gridpoint *gpoint;
-
-    if ([self isFreePosition: dragPoint]) {
-		  [self setNeedsDisplayInRect: dragRect];
+  if (isDragTarget == NO)
+    {
+      return NSDragOperationNone;
     }
 
-		gpoint = gridPoint(self, gridPointSel, p);
-		dragPoint = NSMakePoint(gpoint->x, gpoint->y);
-
-		if (gpoint->used == 0) {
-			dragRect = NSMakeRect(dragPoint.x + 8, dragPoint.y, [dragImage size].width, [dragImage size].height);
-			if (dragImage == nil) {
-				ASSIGN (dragImage, [sender draggedImage]);
-			}
-			[self setNeedsDisplayInRect: dragRect];
-
-		} else {
-      DESTROY (dragImage);
-			return NSDragOperationNone;
-		}
+  if (iconsType == FILES_TAB)
+    {
+      if ((sourceDragMask == NSDragOperationCopy)
+	  || (sourceDragMask == NSDragOperationLink))
+	{
+	  if (dragImage)
+	    {
+	      DESTROY (dragImage);
+	      [self setNeedsDisplayInRect: dragRect]; 
+	    }
+	  return NSDragOperationNone;
 	}
-  
-  if (iconsType == FILES_TAB) { 
-    return NSDragOperationEvery;
-  } else {
-    return NSDragOperationCopy;
-  }
+    }
+
+  if (NSEqualPoints(dragPoint, p) == NO)
+    {
+      gridpoint *gpoint;
+
+      if ([self isFreePosition: dragPoint])
+	{
+	  [self setNeedsDisplayInRect: dragRect];
+	}
+
+      gpoint = gridPoint(self, gridPointSel, p);
+      dragPoint = NSMakePoint(gpoint->x, gpoint->y);
+
+      if (gpoint->used == 0)
+	{
+	  dragRect = NSMakeRect(dragPoint.x + 8, dragPoint.y, [dragImage size].width, [dragImage size].height);
+	  if (dragImage == nil)
+	    {
+	      ASSIGN (dragImage, [sender draggedImage]);
+	    }
+	  [self setNeedsDisplayInRect: dragRect];
+
+	}
+      else
+	{
+	  DESTROY (dragImage);
+	  return NSDragOperationNone;
+	}
+    }
+
+  return NSDragOperationEvery;
 }
 
 - (void)draggingExited:(id <NSDraggingInfo>)sender
 {
-	if (dragImage != nil) {
-		DESTROY (dragImage);
-    [self setNeedsDisplay: YES];
-	}
+  if (dragImage != nil)
+    {
+      DESTROY (dragImage);
+      [self setNeedsDisplay: YES];
+    }
 
-	isDragTarget = NO;
+  isDragTarget = NO;
 }
 
 - (BOOL)prepareForDragOperation:(id <NSDraggingInfo>)sender
 {
-	return isDragTarget;
+  return isDragTarget;
 }
 
 - (BOOL)performDragOperation:(id <NSDraggingInfo>)sender
 {
-	return YES;
+  return YES;
 }
 
 - (void)concludeDragOperation:(id <NSDraggingInfo>)sender
@@ -1358,10 +1426,10 @@
             {
               for (i = 0; i < [icons count]; i++)
                 {
-                  TShelfIcon *icon = [icons objectAtIndex: i];
+                  TShelfFileIcon *icon = [icons objectAtIndex: i];
                   if ([[icon paths] isEqualToArray: sourcePaths])
                     {
-                      gpoints[[icon gridindex]].used = 0;
+                      gpoints[[icon gridIndex]].used = 0;
                       gpoint->used = 1;					  
                       [icon setGridIndex: index];
                       [self resizeWithOldSuperviewSize: [self frame].size];        	  
