@@ -1,8 +1,9 @@
 /* TShelfPBIcon.h
  *  
- * Copyright (C) 2003-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2003-2021 Free Software Foundation, Inc.
  *
- * Author: Enrico Sersale <enrico@imago.ro>
+ * Authors: Enrico Sersale <enrico@imago.ro>
+ *          Riccardo Mottola <rm@gnu.org>
  * Date: August 2001
  *
  * This file is part of the GNUstep GWorkspace application
@@ -27,25 +28,16 @@
 
 #import <AppKit/NSView.h>
 
+#import "TShelfIcon.h"
+
 @class NSImage;
 @class NSBezierPath;
 @class TShelfIconsView;
 
-@interface TShelfPBIcon : NSView
+@interface TShelfPBIcon : TShelfIcon
 {
   NSString *dataPath;
   NSString *dataType;
-
-  NSImage *icon;
-  NSBezierPath *highlightPath;
-  NSPoint position;
-  NSUInteger gridindex;
-
-  TShelfIconsView *tview;
-
-  BOOL isSelect;
-  
-  int dragdelay;
 }
 
 + (NSArray *)dataTypes;
@@ -61,39 +53,14 @@
 
 - (NSData *)data;
 
-- (NSImage *)icon;
-
-- (void)select;
-
-- (void)unselect;
-
-- (BOOL)isSelect;
-
-- (void)setPosition:(NSPoint)pos;
-
-- (NSPoint)position;
-
-- (void)setGridIndex:(NSUInteger)index;
-
-- (NSUInteger)gridindex;
-
-- (NSTextField *)myLabel;
-
 @end
 
 @interface TShelfPBIcon (DraggingSource)
 
-- (void)startExternalDragOnEvent:(NSEvent *)event
-                 withMouseOffset:(NSSize)offset;
-
 - (void)declareAndSetShapeOnPasteboard:(NSPasteboard *)pb;
 
 - (NSDragOperation)draggingSourceOperationMaskForLocal:(BOOL)flag;
 
-- (void)draggedImage:(NSImage *)anImage 
-						 endedAt:(NSPoint)aPoint 
-					 deposited:(BOOL)flag;
-
 @end
 
 #endif // TSHELF_PB_ICON_H
