@@ -1,6 +1,6 @@
 /* WorkspaceApplication.m
  *  
- * Copyright (C) 2006-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2006-2016 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2006
@@ -45,7 +45,7 @@
                       source:(NSString *)source 
                  destination:(NSString *)destination 
                        files:(NSArray *)files 
-                         tag:(int *)tag
+                         tag:(NSInteger *)tag
 {
   if (loggingout == NO)
     {
@@ -61,7 +61,7 @@
       else
 	NSLog(@"performFileOperation: source is nil");
 
-      if (destination == nil && [operation isEqualToString:@"NSWorkspaceRecycleOperation"])
+      if (destination == nil && [operation isEqualToString:NSWorkspaceRecycleOperation])
 	destination = [self trashPath];
       if (destination != nil)
 	[opdict setObject: destination forKey: @"destination"];
@@ -655,6 +655,7 @@
 
 - (void)applicationTerminated:(GWLaunchedApp *)app
 {
+  NSLog(@"WorkspaceApplication applicationTerminated: %@", app);
   if (app == activeApplication) {
     activeApplication = nil;
   }
