@@ -1,6 +1,6 @@
 /* TimeDateView.m
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2004
@@ -22,10 +22,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <Foundation/Foundation.h>
-#include <AppKit/AppKit.h>
-#include "TimeDateView.h"
-#include "Inspector.h"
+#import <Foundation/Foundation.h>
+#import <AppKit/AppKit.h>
+#import "TimeDateView.h"
+#import "Inspector.h"
 
 static const int tf_posx[11] = { 5, 14, 24, 28, 37, 40, 17, 17, 22, 27, 15 };
 static const int posy[4]  = { 1, 13, 29, 38 };
@@ -49,32 +49,33 @@ static const int posy[4]  = { 1, 13, 29, 38 };
 
 - (id)initWithFrame:(NSRect)frameRect
 {
-	self = [super initWithFrame: frameRect];
+  self = [super initWithFrame: frameRect];
   
-	if (self) {
-		maskImage = nil;
-    yearlabel = [NSTextFieldCell new];
-		[yearlabel setFont: [NSFont systemFontOfSize: 8]];
-		[yearlabel setAlignment: NSCenterTextAlignment];    
-	}
+  if (self)
+    {
+      maskImage = nil;
+      yearlabel = [NSTextFieldCell new];
+      [yearlabel setFont: [NSFont systemFontOfSize: 8]];
+      [yearlabel setAlignment: NSCenterTextAlignment];    
+    }
   
-	return self;
+  return self;
 }
 
 - (void)setDate:(NSCalendarDate *)adate
 {
   CREATE_AUTORELEASE_POOL (pool);
   NSBundle *bundle;
-	NSString *imgName;
+  NSString *imgName;
   NSString *imagepath;
   NSImage *image;
- 	int n, hour, minute, dayOfWeek, dayOfMonth, month;
+  int n, hour, minute, dayOfWeek, dayOfMonth, month;
 	
-	hour = [adate hourOfDay];
-	minute = [adate minuteOfHour];
-	dayOfWeek = [adate dayOfWeek];
-	dayOfMonth = [adate dayOfMonth];
-	month = [adate monthOfYear];
+  hour = [adate hourOfDay];
+  minute = [adate minuteOfHour];
+  dayOfWeek = [adate dayOfWeek];
+  dayOfMonth = [adate dayOfMonth];
+  month = [adate monthOfYear];
 
   bundle = [NSBundle bundleForClass: [Inspector class]];
   
@@ -83,150 +84,150 @@ static const int posy[4]  = { 1, 13, 29, 38 };
 	ASSIGN (maskImage, image);
   RELEASE (image);
  
-	//
-	// hour
-	//
-	n = hour/10;
-	imgName = [NSString stringWithFormat: @"LED-%d", n];		
+  //
+  // hour
+  //
+  n = hour/10;
+  imgName = [NSString stringWithFormat: @"LED-%d", n];		
   imagepath = [bundle pathForResource: imgName ofType: @"tiff"];
   image = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-	ASSIGN (hour1Image, image);
+  ASSIGN (hour1Image, image);
   RELEASE (image);
 	
-	n = hour%10;		
-	imgName = [NSString stringWithFormat: @"LED-%d", n];
+  n = hour%10;		
+  imgName = [NSString stringWithFormat: @"LED-%d", n];
   imagepath = [bundle pathForResource: imgName ofType: @"tiff"];
   image = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-	ASSIGN (hour2Image, image);
+  ASSIGN (hour2Image, image);
   RELEASE (image);
   
   imagepath = [bundle pathForResource: @"LED-Colon" ofType: @"tiff"];
   image = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-	ASSIGN (hour3Image, image);
+  ASSIGN (hour3Image, image);
   RELEASE (image);
 
-	//
-	// minute
-	//
-	n = minute/10;
-	imgName = [NSString stringWithFormat: @"LED-%d", n];
+  //
+  // minute
+  //
+  n = minute/10;
+  imgName = [NSString stringWithFormat: @"LED-%d", n];
   imagepath = [bundle pathForResource: imgName ofType: @"tiff"];
   image = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-	ASSIGN (minute1Image, image);
+  ASSIGN (minute1Image, image);
   RELEASE (image);
-
-	n = minute%10;
-	imgName = [NSString stringWithFormat: @"LED-%d", n];
+  
+  n = minute%10;
+  imgName = [NSString stringWithFormat: @"LED-%d", n];
   imagepath = [bundle pathForResource: imgName ofType: @"tiff"];
   image = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-	ASSIGN (minute2Image, image);
+  ASSIGN (minute2Image, image);
   RELEASE (image);
 
-	//
-	// dayOfWeek
-	//
-	imgName = [NSString stringWithFormat: @"Weekday-%d", dayOfWeek];
+  //
+  // dayOfWeek
+  //
+  imgName = [NSString stringWithFormat: @"Weekday-%d", dayOfWeek];
   imagepath = [bundle pathForResource: imgName ofType: @"tiff"];
   image = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-	ASSIGN (dayweekImage, image);
+  ASSIGN (dayweekImage, image);
   RELEASE (image);
 
-	//
-	// dayOfMonth
-	//
-	n = dayOfMonth/10;
-	imgName = [NSString stringWithFormat: @"Date-%d", n];
+  //
+  // dayOfMonth
+  //
+  n = dayOfMonth/10;
+  imgName = [NSString stringWithFormat: @"Date-%d", n];
   imagepath = [bundle pathForResource: imgName ofType: @"tiff"];
   image = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-	ASSIGN (daymont1Image, image);
+  ASSIGN (daymont1Image, image);
   RELEASE (image);
 
-	n = dayOfMonth%10;
-	imgName = [NSString stringWithFormat: @"Date-%d", n];
+  n = dayOfMonth%10;
+  imgName = [NSString stringWithFormat: @"Date-%d", n];
   imagepath = [bundle pathForResource: imgName ofType: @"tiff"];
   image = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-	ASSIGN (daymont2Image, image);
+  ASSIGN (daymont2Image, image);
   RELEASE (image);
 
-	//
-	// month
-	//
-	n = month;
-	imgName = [NSString stringWithFormat: @"Month-%d", n];
+  //
+  // month
+  //
+  n = month;
+  imgName = [NSString stringWithFormat: @"Month-%d", n];
   imagepath = [bundle pathForResource: imgName ofType: @"tiff"];
   image = [[NSImage alloc] initWithContentsOfFile: imagepath]; 
-	ASSIGN (monthImage, image);
+  ASSIGN (monthImage, image);
   RELEASE (image);
-
-  [yearlabel setStringValue: [NSString stringWithFormat: @"%d", [adate yearOfCommonEra]]];
+  
+  [yearlabel setStringValue: [NSString stringWithFormat: @"%li", (long int)[adate yearOfCommonEra]]];
 
   RELEASE (pool);
-	[self setNeedsDisplay: YES];
+  [self setNeedsDisplay: YES];
 }
 
 - (void)drawRect:(NSRect)rect
 {
-	NSRect r;
-	NSSize s; 
-	NSPoint p;
-	float h;
+  NSRect r;
+  NSSize s; 
+  NSPoint p;
+  CGFloat h;
 	
-	if (maskImage == nil) {
-		return;
-	}
+  if (maskImage == nil) {
+    return;
+  }
   
   s = [maskImage size];
-	h = s.height;
+  h = s.height;
   r = NSInsetRect(rect, (rect.size.width - s.width)/2, 
-													      (rect.size.height - s.height)/2);
-	p = NSMakePoint(r.origin.x, r.origin.y);
-	[maskImage compositeToPoint: NSMakePoint(0, 13) 
+                  (rect.size.height - s.height)/2);
+  p = NSMakePoint(r.origin.x, r.origin.y);
+  [maskImage compositeToPoint: NSMakePoint(0, 13) 
                     operation: NSCompositeSourceOver];
+  
+  //
+  // hour
+  //
+  p.x = tf_posx[0];
+  p.y = h - posy[0];
+  [hour1Image compositeToPoint: p operation: NSCompositeSourceOver];
+  p.x = tf_posx[1];
+  [hour2Image compositeToPoint: p operation: NSCompositeSourceOver];
+  p.x = tf_posx[2];
+  [hour3Image compositeToPoint: p operation: NSCompositeSourceOver];
+  
+  //
+  // minute
+  //
+  p.x = tf_posx[3];
+  [minute1Image compositeToPoint: p operation: NSCompositeSourceOver];
+  p.x = tf_posx[4];
+  [minute2Image compositeToPoint: p operation: NSCompositeSourceOver];
 
-	//
-	// hour
-	//
-	p.x = tf_posx[0];
-	p.y = h - posy[0];
-	[hour1Image compositeToPoint: p operation: NSCompositeSourceOver];
-	p.x = tf_posx[1];
-	[hour2Image compositeToPoint: p operation: NSCompositeSourceOver];
-	p.x = tf_posx[2];
-	[hour3Image compositeToPoint: p operation: NSCompositeSourceOver];
-
-	//
-	// minute
-	//
-	p.x = tf_posx[3];
-	[minute1Image compositeToPoint: p operation: NSCompositeSourceOver];
-	p.x = tf_posx[4];
-	[minute2Image compositeToPoint: p operation: NSCompositeSourceOver];
-
-	//
-	// dayOfWeek
-	//
-	p.x = tf_posx[6];
-	p.y = h - posy[1];
-	[dayweekImage compositeToPoint: p operation: NSCompositeSourceOver];
-
-	//
-	// dayOfMonth
-	//
+  //
+  // dayOfWeek
+  //
+  p.x = tf_posx[6];
+  p.y = h - posy[1];
+  [dayweekImage compositeToPoint: p operation: NSCompositeSourceOver];
+  
+  //
+  // dayOfMonth
+  //
   p.x = tf_posx[7];  
   p.y = h - posy[2];
-	[daymont1Image compositeToPoint: p operation: NSCompositeSourceOver];
+  [daymont1Image compositeToPoint: p operation: NSCompositeSourceOver];
   p.x = tf_posx[9];
-	[daymont2Image compositeToPoint: p operation: NSCompositeSourceOver];
-
-	//
-	// month
-	//
+  [daymont2Image compositeToPoint: p operation: NSCompositeSourceOver];
+  
+  //
+  // month
+  //
   p.x = tf_posx[10];
   p.y = h - posy[3];
-	[monthImage compositeToPoint: p operation: NSCompositeSourceOver];
-
+  [monthImage compositeToPoint: p operation: NSCompositeSourceOver];
+  
   [yearlabel drawInteriorWithFrame: NSMakeRect(0, 0, rect.size.width, 12)
-		                        inView: self];
+                            inView: self];
 }
 
 @end
