@@ -1,8 +1,9 @@
 /* ddbd.m
  *  
- * Copyright (C) 2004-2014 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2018 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
+ *         Riccardo Mottola <rm@gnu.org>
  * Date: February 2004
  *
  * This file is part of the GNUstep GWorkspace application
@@ -94,7 +95,7 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
     [conn setDelegate: self];
 
     if ([conn registerName: @"ddbd"] == NO) {
-	    NSLog(@"unable to register with name server - quiting.");
+	    NSLog(@"unable to register with name server - quitting.");
 	    DESTROY (self);
 	    return self;
 	  }
@@ -172,7 +173,7 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
     }
   NS_HANDLER
     {
-      NSLog(@"A fatal error occured while detaching the thread!");
+      NSLog(@"A fatal error occurred while detaching the thread!");
     }
   NS_ENDHANDLER
 }
@@ -196,7 +197,7 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
     }
   NS_HANDLER
     {
-      NSLog(@"A fatal error occured while detaching the thread!");
+      NSLog(@"A fatal error occurred while detaching the thread!");
     }
   NS_ENDHANDLER
 }
@@ -278,7 +279,7 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
     }
   NS_HANDLER
     {
-      NSLog(@"A fatal error occured while detaching the thread!");
+      NSLog(@"A fatal error occurred while detaching the thread!");
     }
   NS_ENDHANDLER
 }
@@ -414,11 +415,11 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
     NSArray *origfiles = [updinfo objectForKey: @"origfiles"];
     NSMutableArray *srcpaths = [NSMutableArray array];
     NSMutableArray *dstpaths = [NSMutableArray array];
-    int i;
+    NSUInteger i;
     
     if ([operation isEqual: @"GWorkspaceRenameOperation"]) {
-      srcpaths = [NSArray arrayWithObject: source];
-      dstpaths = [NSArray arrayWithObject: destination];
+      srcpaths = [NSMutableArray arrayWithObject: source];
+      dstpaths = [NSMutableArray arrayWithObject: destination];
     } else {
       if ([operation isEqual: NSWorkspaceDuplicateOperation]) { 
         for (i = 0; i < [files count]; i++) {
@@ -449,8 +450,8 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
 
 BOOL subpath(NSString *p1, NSString *p2)
 {
-  int l1 = [p1 length];
-  int l2 = [p2 length];  
+  NSUInteger l1 = [p1 length];
+  NSUInteger l2 = [p2 length];  
 
   if ((l1 > l2) || ([p1 isEqualToString: p2])) {
     return NO;
